moe_Idiom = ["一日到暗","一半日仔","人情世事","三心兩意","上卌袂攝","山伯英台","三除四扣","大富大貴","不敢當","天反地亂","月外日","毋甘嫌","毋甘願","毋成人","毋成樣","心狂火著","反來反去","毋知死","歹剃頭","毋是勢","反倒轉","毋情願","夭壽短命","心驚膽嚇","仙拚仙","仝爸各母","央三託四","卯死矣","去傷解鬱","加講話","平","正當時","用","在欉黃","好好人","如此如此","好育飼","尖跤幼手","有一無兩","死人款","有耳無喙","死坐活食","有的無的","有空無榫","有要緊","有時有陣","收跤洗手","死路旁","死賴人","百百空","自作孽","行後尾門","吵家抐宅","吵家抐計","刣雞教猴","弄狗相咬","求神問佛","走袂開跤","走袂離","走赦馬","佯毋知","佯顛佯戇","卸世眾","初見面","卸祖公","受袂起","卸責任","受當袂起","姑換嫂","孤𣮈絕種","孤毛絕種","拖身拖命","拖屎連","拆食落腹","放粉鳥","拍通關","拚暝工","抽豬母稅","東倒西歪","爸老囝幼","花袂牢枝","青面獠牙","迎新棄舊","近廟欺神","青磅白磅","促歲壽","哀爸叫母","哎喲喂","度小月","幽幽仔疼","挖心肝","是按怎","枵飽吵","洗門風","流豬哥瀾","相交插","相卸代","相挨相𤲍","紅膏赤蠘","若有若無","重敧爿","食外口","食便領現","食清領便","食軟驚硬","食膨餅","食頭路","風聲嗙影","哭爸哭母","唔唔睏","崁頭崁面","料想袂到","氣身惱命","烏白來","消災解厄","消瘦落肉","烏魯木齊","笑頭笑面","袂收山","袂按算","袂食袂睏","袂得過","袂輸講","袂講得","袂伸捙","起毛䆀","起毛婸","起跤動手","起藥蛆","釘孤枝","鬥做伙","假仙假觸","假好衰","假死假活","偷來暗去","偷咬雞仔","假鬼假怪","娶新婦","惜命命","徛衛兵","捽目尾","掠交替","掠沙筋","掠兔仔","掠坦橫","掠長補短","掠無頭摠","掠龜走鱉","欲死欲活","欲呢","添福壽","粗菜便飯","軟塗深掘","陳三五娘","善男信女","啼啼哭哭","割稻仔尾","插一跤","插喙插舌","敢毋是","敢有","無一定","無了時","無大無細","無天理","無代無誌","無打緊","無良心","無事使","無依無倚","無奈","無奈何","無所謂","無法伊","無法度","無法無天","無某無猴","無要無緊","無要緊","無啥物","無啥貨","無意無思","無暝無日","無影無跡","無錯","無聲無說","無講無呾","無礙著","痠抽疼","硬拄硬","著賊偷","趁流水","費氣費觸","傳後嗣","傷風敗俗","傷腦筋","幌韆鞦","想東想西","想空想縫","搧大耳","搵豆油","搦屎搦尿","搝搝搦搦","楔手縫","照步來","照呼照行","當頭白日","當頭對面","落人的喙","舅仔探房","腹肚枵","落空逝","試看覓","裝痟的","跤尖手幼","跤來手來","趒跤頓蹄","較快","飼查某","頓椅頓桌","嘛是","僫做","嘛欲","嘈嘈滴","僫講","慢行","慢慢仔是","摸無路","滿四界","滲屎尿","滿滿是","漲懸價","管待伊","算袂和","算無盤","綴人走","綿死綿爛","緊事寬辦","綴前綴後","鉸刀爿","屧手縫","寬寬仔是","憂頭結面","霆水螺","噪人耳","激怐怐","瞞天過海","糖甘蜜甜","膨肚短命","謀財害命","隨在你","頭眩目暗","聲聲句句","講大聲話","軁錢空","轉彎踅角","雙面刀鬼","癩𰣻爛癆","纏跤絆手","鐵骨仔生","鐵齒銅牙槽","顧人怨","顧三頓","彎來斡去","觀前顧後","𠢕吮食","𬦰懸𬦰低","勼跤勼手","反起反倒","手梳攑懸","水崩山","王見王","含血霧天","厚操煩","重本","食好料","捎無摠","疼命命","啉酒醉","通人知","喝起喝倒","無天良","無捨施","無盤","會記得","跤麻手痺","實䈄","算會和","頭轉客","離跤手","一必一中","人懸漢大","大人大種","大目孔","大身大命","大嚨喉空","天公地道","心狂火熱","心花開","心慒慒","手爪賤","手面趁食","手縫櫳","月圍箍","歹面相看","歹紡","牛聲馬喉","半老老","司公仔象桮","生頭凊面","交落身","好死毋死","好唯是","有路無厝","行袂開跤","忘恩背義","辛苦病疼","卸世卸眾","孤跤手","侵門踏戶","南北二路","挑花刺繡","枵飢失頓","枵過飢","流汗流洘","為非糝做","看破跤手","看袂上目","面漚面臭","食人夠夠","食老出癖","食重鹹","食銅食鐵","挽瓜揫藤","梳妝打扮","氣暢忍","袂做得","袂博假博","袂曉衰","起酒痟","起蛟龍","迵海","夠月","惜花連盆","牽龜落湳","笨跤笨手","規碗捀","規嚾規黨","頂下歲","博士博","喙笑目笑","報鳥鼠仔冤","惡人無膽","欺貧重富","無才","硩番薯","順行","搝後跤","搭胸坎","會得過","準拄煞","腰痠背疼","萬丈深坑","倚山食山","挨挨陣陣","漚戲拖棚","趖跤趖手","閬雨縫","燖補","縛跤縛手","親疊親","無底代","頭較大身","戴小鬼仔殼","臨時臨曜","鏨頭短命","鹹酸苦汫","攑香綴拜","灇水","變工藝","變啥魍","金言玉語","好食睏","大趁錢","落空車","規山坪","海水倒激"]


DT_Idiom = ["痟狗舂墓壙",
            "船過水無痕",
            "毛呼龜粿粽",
            "識皮包戇餡",
            "過五關斬六將",
            "過五關",
            "斬六將"
            "一刀兩斷",
            "倚海食海",
            "禽獸不如",
            "花天酒地",
            "風調雨順",
            "毋知死活",
            "青盲精",
            "啞口靈",
            "大尊大",
            "細尊細",
            "洞房花燭夜",
            "金榜題名時",
            "三分天註定",
            "七分靠拍拚",
            "胭脂馬拄著關老爺",
            "由淺入深",
            "光天化日",
            "家財萬貫",
            "見講見對",
            "一仙五厘",
            "來者是客",
            "一工到暗",
            "談情說愛",
            "馬耳東風",
            "滿面春風",
            "相親相愛",
            "輕聲細說",
            "春風滿面",
            "有頭有尾",
            "偷工減料",
            "雙跤踏雙船",
            "虎頭鳥鼠尾",
            "食好鬥相報",
            "無三日的好光景",
            "無三日好光景"
            ]


DT_Modifier = ["無細膩",
               "差不多",
               "自然",
               "主要",
               "一定",
               "一般",
               "一併",
               "一同",
               "一致",
               "一身",
               "一共",
               "細條",
               "大條",
               "大圈",
               "無論",
               "無局",
               "營養",
               "合理",
               "揜貼",
               "牢牢",
               "親身",
               "焦鬆",
               "勇敢",
               "慎重",
               "真濟",
               "真湳",
               "真仁",
               "要緊",
               "凡勢",
               "真普遍",
               "普遍",
               "富",
               "誠濟",
               "驚人",
               "忘恩背義",
               "鐵骨仔生",
               "尖跤幼手",
               "挨挨陣陣",
               "若有若無",
               "在欉黃",
               "活跳跳",
               "插插插",
               "無盤",
               "上好",
               "主動",
               "圇圇",
               "蠻皮",
               "安靜",
               "滾滾",
               "昭昭",
               "原本",
               "原來",
               "足吵",
               "足遠",
               "足足",
               "公立",
               "私立",
               "國立",
               "才閣",
               "斷掌",
               "離譜",
               "烏白",
               "黑白",
               "粗魯",
               "複雜",
               "較早",
               "較晏",
               "較芳",
               "水水",
               "的確",
               "明顯",
               "好空",
               "好命",
               "好運",
               "好看",
               "好聽",
               "好食",
               "好抱",
               "好命底",
               "好禮仔",
               "好唯是",
               "好聲說",
               "歹命",
               "歹食",
               "歹運",
               "歹吉兆",
               "迫促",
               "出在",
               "文雅",
               "較委屈",
               "誠長",
               "長途",
               "長期",
               "短期",
               "短站",
               "短命",
               "條直",
               "精密",
               "殘忍",
               "透透",
               "夠水",
               "夠月",
               "特別",
               "大概",
               "大細聲",
               "軟㽎㽎",
               "金爍爍",
               "欲倒欲倒",
               "大空細裂",
               "對同仔對同",
               "現現",
               "平平",
               "生生",
               "恬恬",
               "有效",
               "無效",
               "有穿",
               "有閒",
               "有閒工",
               "總是",
               "做伙",
               "困難",
               "艱難",
               "夭壽",
               "激烈",
               "寶貴",
               "開闊",
               "正經",
               "正當",
               "清廉",
               "清楚",
               "輕便",
               "嘛欲",
               "少年",
               "困苦",
               "值錢",
               "野味",
               "奸巧",
               "細膩",
               "絕對",
               "實在",
               "爾爾",
               "歹空",
               "真正",
               "用得",
               "適合",
               "寒酸",
               "可惡",
               "可愛",
               "巷仔內的",
               "凊凊彩彩",
               "甘甜",
               "半精白",
               "總共",
               "貴重",
               "詼諧",
               "真花",
               "真害",
               "該然",
               "早期",
               "中期",
               "晚期",
               "誠皮",
               "獨裁",
               "獨身",
               "白目",
               "臭耳",
               "久長",
               "久久長長",
               "無要緊",
               "相連紲",
               "無才",
               "誠懸",
               "奇怪",
               "小心",
               "孤單",
               "孤獨",
               "厲害",
               "老練",
               "直直",
               "直溜溜",
               "公平",
               "嚴重",
               "簡單",
               "當然",
               "散赤",
               "䆀猴",
               "誠懇",
               "砧砧",
               "爽快",
               "穩心仔",
               "開明",
               "吉祥",
               "如意",
               "平安",
               "充分",
               "專業",
               "公共",
               "完整",
               "實施",
               "小可",
               "急性",
               "提早",
               "撥開",
               "撫養",
               "大漢",
               "播出",
               "擔憂",
               "改薰",
               "改革",
               "新亡",
               "神奇",
               "耐用",
               "貧窮",
               "首輪",
               "齊全",
               "慢性",
               "急性",
               "凍霜",
               "自由",
               "安全",
               "安定",
               "偏偏",
               "方便",
               "大方",
               "一品",
               "二品",
               "劇烈",
               "死鹹",
               "整齊",
               "空空",
               "人造",
               "規擔",
               "譀古",
               "具體",
               "真靈",
               "閃閃",
               "連續",
               "精彩",
               "二來",
               "無奈",
               "憂頭結面",
               "簡簡單單",
               "糜糜卯卯",
               "情投意合",
               "鬚聳目降",
               "金光閃閃",
               "閃閃爍爍",
               "瑞氣千條",
               "有家有後",
               "老神在在",
               "馬西馬西",
               "當頭對面",
               "一勻塗",
               "不得了",
               "無仝款",
               "無好尾",
               "無聊",
               "袂赴",
               "快活",
               "垃儳",
               "大箍",
               "富裕",
               "危險",
               "確實",
               "下痟",
               "代先",
               "辛苦",
               "黏黏",
               "去去倒倒",
               "滿四界",
               "走第一",
               "好育飼",
               "害害去",
               "強強欲",
               "實捅捅",
               "博士博",
               "博",
               "現",
               "奅",
               "炎",
               "狂",
               "雄",
               "疏",
               "細",
               "暗",
               "疏遠",
               "直接",
               "互相",
               "博學",
               "根本",
               "強欲",
               "清涼",
               "好用",
               "大力",
               "小力",
               "緊性",
               "惡",
               "寒",
               "久",
               "醉",
               "猶",
               "野",
               "先",
               "拄拄",
               "拄好",
               "拄拄好",
               "袂拄好",
               "硬迸迸",
               "磕袂著",
               "手爪賤",
               "歹心行",
               "一箍槌槌",
               "猴猴",
               "有通",
               "正範",
               "私奇",
               "輾轉",
               "仝班",
               "正常",
               "正面",
               "負面",
               "復古",
               "十足",
               "較快",
               "較慢",
               "較清",
               "較清彩",
               "較明",
               "較開",
               "楦大",
               "老罔老",
               "無天良",
               "無良心",
               "無天理",
               "甜粅粅",
               "花花",
               "苦苦",
               "自排",
               "自願",
               "雙重",
               "夠力",
               "衰洨",
               "衰小",
               "赤跤",
               "大粒",
               "爛爛",
               "拄搪",
               "大約",
               "豪爽",
               "果然",
               "較清心",
               "高速",
               "慢速",
               "惡質",
               "並濟",
               "不仁",
               "熟手",
               "萬無一失",
               "清心",
               "多多",
               "快樂",
               "高級",
               "有時",
               "違法",
               "皺皺",
               "較準",
               "興興",
               "較低級",
               "自私",
               "正當時",
               "平等",
               "厚重",
               "明明",
               "純天然",
               "天然",
               "彎來斡去",
               "末趁",
               "好趁",
               "重",
               "上鮮",
               "較重",
               "善良",
               "心慒慒",
               "鬼鬼祟祟",
               "醬醬醬",
               "反常",
               "順利",
               "長進",
               "天生",
               "重鹹",
               "重要",
               "重大",
               "樸實",
               "死酸",
               "活潑",
               "嚴格",
               "便利",
               "中立",
               "中央",
               "希罕",
               "透流",
               "詳細",
               "較倚",
               "較貴",
               "努力",
               "豐富",
               "食賰",
               "殕殕",
               "細枝",
               "真甘",
               "老實",
               "就近",
               "正港",
               "內行",
               "細跤",
               "臭香",
               "臭老",
               "七少年八少年",
               "放心仔",
               "通人知",
               "豬狗牛",
               "好份",
               "平歲",
               "平懸",
               "平安",
               "烏鉎",
               "親手",
               "怪怪",
               "客氣",
               "堅定",
               "傷重",
               "到尾",
               "相關",
               "二手",
               "準時",
               "蓋懸",
               "尾仔",
               "親目",
               "過份",
               "牢",
               "涼",
               "滿",
               "大",
               "圓",
               "直",
               "𠕇",
               "一等一",
               "無捨施",
               "袂講得",
               "無底代",
               "無礙著",
               "飛飛",
               "冗",
               "滇",
               "老",
               "幼",
               "齪",
               "怙",
               "散",
               "好",
               "肥",
               "假",
               "歹",
               "苛",
               "愈",
               "素",
               "賰",
               "煞",
               "奇",
               "平",
               "小",
               "iap-thiap",
               "chē",
               "順sòa",
               "kāng款",
               "kau-penn", "kau-pinn", "ji̍p-ní", "li̍p-ní", "kim-siak-siak", "pe̍h-tsiánn-bô-bī", "pîng-kin", "pîng-kun", "nā-sī", "sí-ba̍k", "guā-nī", "tông-sî", "lio̍h-lio̍h-á", "tsiòng-tsâi", "bián siàu-siūnn", "bū-bū", "thàu-àm", "pháinn-khuànn-bīn", "phái-khuànn-bīn", "kui-bué", "kui-bé", "tuā-ba̍k-khóng", "tú-tshiāng", "ē-tit-thang", "ngia̍uh-ngia̍uh-sô", "ka-tsài", "tāi-liōng", "ha̍p-sǹg", "pn̄g-tháng", "tuā-pah", "nńg-sim", "pah-bīn", "piān-piān", "tsi̍t-khùn-á", "kong-ka", "ē-tit", "bān-tshiánn-sī", "ū-kàu", "tiau-kòo-ì", "iù-siù", "bô-tú-hó", "tshoo-tāng", "tian-tò-píng", "thòo-hueh", "thòo-huih", "khui-khuah", "luān-tshau-tshau", "puàn-suī", "sai-khia", "hó-khuànn-thâu", "bái-tsâi", "kìng-jiân", "kìng-liân", "bīn-thâu-tsîng", "suà-phah", "hó-tit", "tsí-iàu", "tshio-tiô", "tsia̍p-tsia̍p", "tuā-sì-kè", "tuā-sì-kuè", "sáng-sè", "tsiūnn-tshiú", "siōng-ke", "tsik-sî", "sūn-suà", "khó-pí", "pênn-pênn", "pînn-pînn", "tshing-khì-siùnn", "tshuah-lâu", "tī-tang-sî", "tú-tsiah", "muí-ji̍t", "muí-li̍t", "sù-siông", "tîng-puē", "tsū-ngóo", "thán-tshiò", "kha̍p-bē-tio̍h", "kha̍p-buē-tio̍h", "tīng-tauh", "ti̍t-ti̍t", "tsá-tsîng", "bián-kióng", "tshì-tsha̍k", "uî-lân", "khak-si̍t", "iōng-sim", "bô-tik-khak", "put-sî", "lí-kái", "phah-piànn", "pháinn-sí", "luán-jio̍k", "luán-lio̍k", "kui-kí", "kui-kú", "ná-tshiūnn", "khik-khui", "tīng-khok-khok", "uan-iunn", "ta̍k-pái", "suà-tshuì", "tshoo-tshoo", "kiat-si̍t", "nā-bô", "put-tik-liáu", "kó-jiân", "kó-liân", "iû-tsāi", "kau-tînn", "kan-kan-á", "luî-thuî", "sann-kap", "tsa̍p-tshài-mī", "nā-tsún", "thìng-hó", "it-ti̍t", "phòng-sai-sai", "thàu-bué", "thàu-bé", "tsi̍t-puànn", "tsi̍t-kuá-á", "tsuân-jiân", "tsuân-liân", "khang-thâu", "kang-hu", "lo̍h-lâi", "m̄ hó-sè", "ké-iánn", "tshiah-ia̍h", "nńg-tsiánn", "tshiâng-tsāi", "si̍p-tsuân", "siāng-khuán", "pún-tsiânn", "tang-sî", "tshim-khik", "ian-n̄g", "khi-khiau", "pe̍h-ba̍k", "khì-tò", "ua̍h-huē", "ua̍h-hē", "ti̍t-liu-liu", "kàu-pún", "kong-khui", "suî-sî", "thiau-kang", "tsiong-kî-bué", "tsiong-kî-bé", "pe̍h-pe̍h", "thán-ti̍t", "thian-tho̍h", "thàu-té", "thàu-tué", "pau-ún", "siông-sè", "siàu-liân", "tshóng-pōng", "pōo-pîn", "tsiànn-pān", "ngē-piàng-piàng", "ngī-piàng-piàng", "tham-tsâi", "thâu-bué", "thâu-bé", "hong-so", "bô-guā-kú", "sio-kāng", "pá-tsuí", "tshiú-kang", "liāu-siáu", "tsí-sī", "kuì-khì", "tsìng-king", "hó-tshuì", "ìnn-ònn", "tsū-thâu", "kai-tong", "pân-gî", "ua̍h-tāng", "pó-siú", "pún-lâi", "ua̍h-tsuí", "tuā-hàn", "ngē-tshah", "ngī-tshah", "hô-khóo", "tong-sî", "kàu-sî", "koo-khu̍t", "lī-king", "sí-lâng", "tshù-bī", "sin-khóo", "pháinn-khuànn", "siáu-siáu", "kìnn-bīn", "tshiú-tshìng", "tsi̍t-kuá", "kong-khai", "kiau-ngōo", "lâu-tsî", "it-lu̍t", "hiám-hiám", "hán-hán--á", "lóng-tsóng", "niā-niā", "bâ-pì", "kan-hiu", "tsiâu-ûn", "tshin-tshiūnn", "tshiánn-bān", "liâu-liâu-á", "tsó-iū", "kuè-āu", "kè-āu", "ing-kai-jiân", "ing-kai-liân", "tâng-tsê", "tsí-hó", "lán-si", "sio-tshuā", "bô-ì-tiong", "guā-guā", "hue-pa-li-niau", "kú-kú", "tshìn-tshái", "uá-nî", "āu-thâu", "tsa̍p-tsn̂g", "siong-tiōng", "ta̍uh-ta̍uh-á", "tshing-tsīng", "buē-tsîng-buē", "bē-tsîng-bē", "liân-suà", "ke-kiám", "tshun-ûn", "phùn-tiám", "bān-sìng", "kiōng-kiōng", "áng-láng", "bué--lâi", "bé--lâi", "kán-tan", "tsia̍h-tshī", "tàu-tah", "tsua̍t-tuì", "huí-luī", "ū-la̍t", "lân-bián", "kan-sîn", "tāi-hong", "ū-tang-sî-á", "senn-pún", "sinn-pún", "huann-hí", "līng-guā", "bo̍k-tsiân", "to̍k-to̍k", "tshân-tshân", "tshím-thâu", "sí-huē", "sí-hē", "khuah-bóng-bóng", "kiàn-nā", "ē-sái", "pe̍h-bah", "sí-tse̍h", "tik-khak", "lān-muā", "tshun-hong", "uì-kuânn", "liú-lia̍h", "tsiong-kīn", "tsiong-kūn", "khuah-tshuì", "thán-khi", "sin-sian", "ki̍k-ke", "tu̍t-jiân", "tu̍t-liân", "pit-jiân", "pit-liân", "uân-tsuân", "tshûn-sí", "tsi̍t-sì-kè", "tsi̍t-sì-kuè", "pat-tin", "pháinn-kiat-tiāu", "phái-kiat-tiāu", "bô-siau", "ta̍p-tih", "bué-tshiú", "bé-tshiú", "liân-sio̍k", "hit-tsūn", "hit-lō", "tsiânn-lâng", "í-tsîng", "kè-sio̍k", "iá-bī", "uè-suè", "è-sè", "khah-ke", "tuā-káng", "ku-ku-pih-pih", "kui-sim", "ū-sî-á", "ji̍t-āu", "li̍t-āu", "pháinn-tshiú-jiáu", "pháinn-tshiú-niáu", "tshoo-ióng", "kám-sī", "tshiâ-ba̍k", "thâu-thiànn", "tsuan-kang", "hán-tit", "uan-óng", "tsáu-tsông", "ngē-tsiānn", "ngī-tsiānn", "tsâi-tsîng", "kuè-tsuí", "kè-tsuí", "phóo-thong", "m̄-nā", "kan-khóo", "thiau-lāng", "hô-pit", "ē-pái", "kū-té", "kū-tué", "nńg-kô-kô", "ná-tshin-tshiūnn", "m̄-guān", "tong-tē", "tong-tuē", "hong-liû", "phú-phú", "it-lia̍p-it", "to̍k-tshâi", "guân-tsāi", "ū-tshun", "it-tīng", "tsiah-nī-á", "kiōng-beh", "kiōng-bueh", "láu-pâi", "tsia̍h-la̍t", "ū-tsîng", "khah-tsá", "kip-sìng", "huâinn-ti̍t", "huînn-ti̍t", "lio̍h-á", "uán-jiân", "uán-liân", "kik-kut", "sè-uī", "suè-uī", "tsiah-nī", "sūn-sè", "tiānn-tio̍h", "pîn-liông-sim", "phah-sǹg", "tsiū-án-ne", "pháinn-khang", "pháinn-sè", "kam-guān", "pháinn-bīn", "phái-bīn", "khó-lîng", "tsi̍t-ha̍k-sái", "lîm-sî", "iáu-m̄-koh", "kiám-tshái", "tshing-tshái", "buē-tsîng", "bē-tsîng", "bān-bān-á", "ji̍t-siông", "li̍t-siông", "li-li-lo-lo", "bîng-bîng", "tio̍h-sî", "tong-tiûnn", "tsīn-tiong", "iáu-siū", "tsiah-sī", "tsiânn-si̍t", "gû-pi", "siōng-kài", "ing-kai", "tsia̍h-hong", "líng-khì", "thóo-kong-á", "sè-hàn", "suè-hàn", "lo̍h-khì", "thâu-tú-á", "tuā-lōo", "sái-tháng", "oo-sian", "tàu-té", "tàu-tué", "sió-sòo", "tsi̍t-tiap-á-kú", "m̄-tú-hó", "tshenn-huan", "tshinn-huan", "siông-siông", "khuìnn-ua̍h", "kánn-sī", "tsá-àm", "bái-kâu", "kha-sau", "kàu-kang", "khuann-khuann-á", "thâu-khí-sing", "sóng-khuài", "thán-huâinn", "thán-huînn", "tàng-sng", "bān-it", "puànn-lōo", "it-khài", "tshit-thô", "bô-tiānn-tio̍h", "ná-thang", "tiām-tiām", "ē-tàng", "uan-uan-uat-uat", "tú-hó", "ló-tshó", "guân-pún", "ū-sî-tsūn", "tsìn-tsîng", "bān-tshiánn", "it-tàn", "khah-thîng-á", "thàu-lâu", "kiàn-pái", "tiau-tî", "puē-kut", "bô-khang", "hô-mí-khóo", "tsū-tsá", "huan-tiám", "thīn-thâu", "sìng-keh", "pháinn-tshuì-táu", "bô-kàu", "bān-bān", "líng-lī", "bô-îng", "tshio-ko", "kám-kóng", "bô-tshái", "sū-āu", "tò-píng", "thán-phak", "su-hā", "lām-sám", "tsiām-tshiánn", "khui-khiàm", "kong-tō", "tsì-tsió", "làu-sái-bé", "sian-tsìn", "bô-gî", "tē-it", "nńg-kut", "mi-mi-mauh-mauh", "ngē-tú-ngē", "ngī-tú-ngī", "tsū-iû", "tsài-sann", "hiān-hiān", "iáu-ū", "tú-tn̄g", "iū-koh", "bān-put-hīng", "tsiàu-siông", "kui-khì", "suà-tshiú", "lo-so", "piànn-miā", "bo̍k-hui", "phoo-pâi", "bē-tit", "buē-tit", "uan-khiau", "khòo-khòo", "tong-jiân", "tong-liân", "lo̍h-bué-tshiú", "lo̍h-bé-tshiú", "m̄-tsiânn-kâu", "iù-khí", "bô-lōo", "tuā-tsâng", "tuā-siann", "tú-teh", "m̄-ta̍t", "tuā-khoo", "khu-sok", "tsīn-li̍k", "luān-sú", "íng-uán", "kuè-hué", "kè-hé", "tng-bīn", "pa-kiat", "khiā-sǹg-kóng", "iáu-koh teh", "khang-tshuì-pōo-tsi̍h", "bâ-bui", "kik-sái", "sí-giān-giān", "m̄-tō", "bān-lîng", "tshiâng-tshiâng-kún", "ha̍p-kai", "bih-tshiu", "àm-bo̍k-bo̍k", "ông-lo̍k-á", "kuánn-kín", "ba̍k-ham", "kuè-ba̍k", "kè-ba̍k", "lím-lím--á", "m̄-bián", "huān-sè", "í-āu", "tsū-pún", "tsē-tsió", "tsuē-tsió", "sîng-jîn", "sîng-lîn", "ún-tàng", "senn-sîng", "sinn-sîng", "nńg-sìm-sìm", "guân-té", "guân-tué", "sua-sap", "bî-bî-á", "án-tsuánn", "sim-sik", "iōng-kong", "būn-būn", "kàu-bué", "kàu-bé", "làu-làu", "íng-íng", "thâu-ba̍k-tsiáu", "sio-jua̍h", "sio-lua̍h", "khóo-khóo", "kuann-liâu", "tò-thâu", "sè-jī", "suè-lī", "kú--lâi", "phah-sńg", "tshing-sim", "koo-láu", "bô-tiunn-tî", "kî-tiong", "hā-siau", "hiau-hīng", "suî-āu", "bē-hù-tshī", "buē-hù-tshī", "tūn-ba̍k", "síng-kang", "tsáu-thiàu", "làng-gue̍h", "làng-ge̍h", "tsá-nî", "lîng-khó", "tsìng-phài", "koh-khah", "iu-guân", "thong-siông", "tsū-té", "tsū-tué", "guân-tsuân", "ke-pô", "tah-tah", "huán-tsíng", "hiān-tú-hiān", "ta̍k-ji̍t", "ta̍k-li̍t", "tsiàu-khí-kang", "tsīn-liōng", "ū-sî", "iau-sò", "tsîng-kàu-tann", "khah-kóng", "tsi̍t-ē", "m̄-thang", "piau-tsún", "tshit-uànn-peh-uànn", "tshit-uànn-pueh-uànn", "āu-bué", "āu-bé", "khì-liáu-liáu", "tāi-sing", "síng-tsînn", "tuā-hīnn", "tuā-hī", "àu-sái", "tshenn-líng", "tshinn-líng", "hàm-kóo", "tîm-té", "tîm-tué", "lūn-tsin", "bī-bián", "lī-hāi", "iù-kut", "ē-īng-tit", "teh-beh", "teh-bueh", "iáu-buē", "iáu-bē", "m̄-kam", "hô-tsê", "hô-tsuê", "tī-sî", "káng-kiù", "uē-sing", "bô-ì-bô-sù", "tshian-bān", "tsì-guān", "bué-á", "bé-á", "siōng-thâu-á", "bô-gî-ngōo", "hó-pháinn", "ki̍p-sî", "put-kuán-sî", "iàu-kín", "bô-kio̍k", "tuā-tōo-kui", "kan-na", "kánn-ná", "án-ne-senn", "án-ní-sinn", "thán-tó", "tâu-ki", "khang-tshiú", "ua̍h-beh", "ua̍h-bueh", "ing-ia", "tng-teh", "táng-hiannh", "muá-ì", "tsha-put-to", "jîn-jîn-jîn", "lîn-lîn-lîn", "hē-sènn-miā", "hē-sìnn-miā", "sim-būn", "kuàn-tsuí", "mé-tshénn", "mé-tshínn", "sua-sua", "àng-tōo", "suî-piān", "gâu-tsá", "it-sing", "tsi̍t-bīn", "tāi-put-liáu", "hiah-nī", "tah-sim", "hó-khuànn", "āu--lâi", "bô-khuì", "tian-tò", "tsim-tsiok", "ū-tsi̍t-ji̍t", "ū-tsi̍t-li̍t", "hiah-nī-á", "hia--ê", "án-ne", "án-ni", "a̍h-tio̍h", "sè-kài", "pún-té", "pún-tué", "thài-pîng", "kui-tshing-bān", "káu-kuài", "thàu-mê", "thàu-mî", "thàn-tsá", "koo-put-jî-tsiong", "koo-put-lî-tsiong", "tshiāng-tú-tshiāng", "bûn-sin", "àu-kóo", "tshinn-tshioh", "liap-sái", "siōng-bô", "giám-ngē", "giám-ngī", "thau-thau-á", "liōng-kî-iok", "pún-thóo", "kuè-tōo", "kè-tōo", "sī-suā", "tsù-sí", "it--lâi", "thóo-huí", "thán-khiā", "hut-jiân", "hut-liân", "bîng-pi̍k", "kàu-kàu", "kāu-sua-sap", "khùn-lân", "tsiànn-bīn", "hiông-hiông", "tsiap-kha", "tú-tú", "kuí-nā kang", "kòo-tīng", "jû-tshú", "lû-tshú", "a̍h-sái", "suah-bué", "suah-bé", "iû-lâi", "sè-tāi", "îng-sin", "hó-sè", "kín-tsua̍h-bān", "kî-si̍t", "puànn-the-tó", "tsāi-sik--ê", "ti̍t-tsiap", "khò-sè", "kàu-tann", "sîng-si̍t", "tsuan-bûn", "kong-ke", "ba̍k-nih-á", "tshi-ko", "li̍k-sik", "tuā-pān", "pîng-siông", "thàu-tsá", "thâu--á", "hia̍p-li̍k", "ē-sái-tit", "tsiām-tsiām", "tiām-tsīng", "iáu-koh", "koh-tsài", "tshiau-kuè", "tshiau-kè", "kiâm-tok-tok", "tshut-thâu", "tiānn-tiānn", "siōng-kú", "phóo-phóo-á", "liâm-mi", "tinn-but-but", "tsiàu-si̍t", "é-káu", "giàn-thâu", "tiâu-ti̍t", "thiám-thâu", "hong-piān", "hó-hó-á", "àm-tiong", "thang-kng", "hó-sim", "tsóng-kiōng", "tshâ-ba̍k"
               ]


#!/usr/bin/env python3
# -*- coding:utf-8 -*-

import json
import os
import platform
import re
import tempfile
import unicodedata
from pprint import pprint

from ArticutAPI import Articut
try:
    from .defaultDict import Taigi_Lexicon
    from .posShift import shiftRule
except:
    from defaultDict import Taigi_Lexicon
    from posShift import shiftRule

BASEPATH = os.path.dirname(os.path.abspath(__file__))

class ArticutTG:
    def __init__(self, username="", apikey="", usernameENG="", apikeyENG=""):
        #self.articut = Articut(username=username, apikey=apikey, url="http://10.1.1.182:50269")
        self.articut = Articut(username=username, apikey=apikey)
        self.articutENG = Articut(username=usernameENG, apikey=apikeyENG, url="https://nlu.droidtown.co")
        self.posPat = re.compile("<[^<]*>([^<]*)</([^<]*)>")
        self.TLPat = re.compile("\s?[\-a-zA-Záíúéóàìùèòâîûêôǎǐǔěǒāīūēō̋̍]+(-+[a-zA-Záíúéóàìùèòâîûêôǎǐǔěǒāīūēō̋̍]+)*\s?")
        self.userDefinedDICT = {}
        self.cjkPAT = re.compile('[\u4e00-\u9fff]')
        self.moeCSV = [[t.replace("\n", "") for t in l.split(",")] for l  in open("{}/defaultDict/moe_dict/詞目總檔.csv".format(BASEPATH), "r", encoding="utf-8").readlines()]
        self.DT_TL = Taigi_Lexicon.DT_TL
        self.purgePat = re.compile("</\w+(_\w+)?><\w+(_\w+)?>|</?\w+(_\w+)?>")
        self.shiftRule = shiftRule
        self.defaultDICT = Taigi_Lexicon.dictCombiner()
        self.legacyLIST = ["", "𪜶𪹚𫝏𫝘𫝙𫝛𫝞𫝺𫝻𫝾𫞭𫞻𫞼𫟂𫟊𫟧𫠛𫣆"]
        self.personPat = re.compile("(?<=<ENTITY_person>)[^<]+(?=</ENTITY_person>)")
    def _pos2Obj(self, posLIST):
        resultLIST = []
        for pos in posLIST:
            if '</' in pos:
                textPosLIST = [[p.group(1), p.group(2)] for p in self.posPat.finditer(pos)]
                # group(0) <ACTION_verb>結帳</ACTION_verb>
                # group(1) 結帳
                # group(2) ACTION_verb
                objLIST = []
                for txt, p in textPosLIST:
                    objLIST.append({
                        "text": txt,
                        "pos": p,
                    })
                if objLIST:
                    resultLIST.append(objLIST)
                else:
                    resultLIST.append([{
                        "text": pos,
                        "pos": 'PUNCTUATION',
                    }])
            else:
                resultLIST.append([{
                    "text": pos,
                    "pos": 'PUNCTUATION',
                }])
        return resultLIST

    def _2TL(self, posLIST):
        '''
        把 posLIST 裡的每一個詞，一一轉為 TL (台羅拼音)
        '''
        resultLIST = []
        for p in posLIST: #p 是一句
            for word in p:
                if "LATIN" in unicodedata.name(word["text"][0]):
                    resultLIST.append(word["text"])
                elif word["text"] in self.DT_TL:
                    resultLIST.append(self.DT_TL[word["text"]])
                elif word["text"] in [token[2] for token in self.moeCSV]:
                    tokenLIST = []
                    for token in self.moeCSV[1:]:
                        if token[2] == word["text"]:
                            tokenLIST.append(token[3])

                    if len(tokenLIST) > 1:
                        resultLIST.append("({})".format("/".join(tokenLIST)))
                    elif len(tokenLIST) == 1:
                        if "/" in tokenLIST[0]:
                            resultLIST.append("({})".format(tokenLIST[0]))
                        else:
                            resultLIST.append("{}".format(tokenLIST[0]))
                    else:
                        pass
                    tokenLIST = []
                else:
                    wordLIST = []
                    tokenLIST = []
                    for t in word["text"]:
                        for token in self.moeCSV:
                            if len(token[2]) == 1 and t == token[2]:
                                tokenLIST.append("{}".format(token[3]))

                        if len(tokenLIST) > 1:
                            wordLIST.append("({})".format("/".join(tokenLIST)))
                        elif len(tokenLIST) == 1:
                            wordLIST.append("{}".format(tokenLIST[0]))
                        tokenLIST = []
                    resultLIST.append("-".join(wordLIST))
        return resultLIST

#<ToDo>
    #def _2POJ(self, postLIST):
        #'''
        #把 posLIST 裡的每一個詞，一一轉為 POJ (白話字拼音)
        #'''
        #resultLIST = []
        #return resultLIST

    #def _2Word(self, posLIST):
        #'''
        #每次從 posLIST 中取一個詞彙，反查這個詞彙是 TL 或 POS 的拼音，依該拼音把同音詞彙找出來，並把這個詞彙同音的台語漢字加入回傳結果中。
        #'''
        #resultLIST = []
        #return resultLIST

    #def _TL2Word(self, TLLIST):
        #'''
        #把 TLLIST (台羅拼音)裡的每一個詞，一一轉為台語漢字
        #'''
        #resultLIST = []
        #return resultLIST

    #def _POJ2Word(self, POJLIST):
        #'''
        #把 POJLIST (白話字拼音)裡的每一個詞，一一轉為台語漢字
        #'''
        #resultLIST = []
        #return resultLIST
#</ToDo>
    def _mixedInputDetector(self, inputSTR):
        TLLIST = [t.group() for t in self.TLPat.finditer(inputSTR)]
        with open(self.TaigiDictFILE.name) as f:
            userDefinedDICT = json.load(f)

        #<特殊區塊：如果使用者有購買英文版 Articut 的使用額度，將調用英文人名偵測。>
        #<否則本功能會在每小時 2000 字免費額度用盡後失效，待下一個小時的免費額度啟用時才恢復>
        knownLIST = []
        for i in TLLIST:
            resultDICT = self.articutENG.parse(i, level="lv1")
            if resultDICT["status"] == True and resultDICT["msg"] == "Success!":
                if "<ENTITY_person>{}</ENTITY_person>".format(i) in "".join(resultDICT["result_pos"]):
                    knownLIST.append(i)
                    userDefinedDICT["ENTITY_person"].append(i)
                    self.userDefinedDICT["ENTITY_person"].append(i)
            else:
                pass
        TLLIST = list(set(TLLIST)-set(knownLIST))
        #</特殊區塊：如果使用者有購買英文版 Articut 的使用額度，將調用英文人名偵測>
        #</否則本功能會在每小時 2000 字免費額度用盡後失效，待下一個小時的免費額度啟用時才恢復>

        if TLLIST == []:
            pass
        else:
            #with open(self.userDefinedDictFILE.name) as f:
                #userDefinedDICT = json.load(f)
            if "_ArticutTaigiUserDefined" in userDefinedDICT.keys():
                userDefinedDICT["_ArticutTaigiUserDefined"].extend(TLLIST)
            else:
                userDefinedDICT["_ArticutTaigiUserDefined"] = TLLIST
            if platform.system() == "Windows":
                self.userDefinedDictFILE = tempfile.NamedTemporaryFile(mode="w+", delete=False)
            else:
                self.userDefinedDictFILE = tempfile.NamedTemporaryFile(mode="w+")
            json.dump(userDefinedDICT, self.userDefinedDictFILE)
            self.userDefinedDictFILE.flush()
        return None

    def _spaceWalker(self, inputDICT):
        '''
        移除非 CJK 字元前後的空格
        '''
        fposPat = re.compile("<UserDefined>\s")
        pposPat = re.compile("\s</UserDefined>")
        posPat = re.compile("</?\w_?[^>]+?>")
        for i in range(0, len(inputDICT["result_pos"])):
            inputDICT["result_pos"][i] = re.sub(fposPat, " <UserDefined>", inputDICT["result_pos"][i])
            inputDICT["result_pos"][i] = re.sub(pposPat, "</UserDefined> ", inputDICT["result_pos"][i])
            inputDICT["result_pos"][i] = inputDICT["result_pos"][i].strip()
        try:
            inputDICT["result_pos"].remove("")
        except:
            pass

        tmpSTR = ""
        for i in range(0, len(inputDICT["result_pos"])):
            tmpSTR = tmpSTR + re.sub(posPat, "<DROIDTOWN_TKBD>", inputDICT["result_pos"][i])
            tmpSTR = tmpSTR.replace("<DROIDTOWN_TKBD><DROIDTOWN_TKBD>", "/").replace("<DROIDTOWN_TKBD> <DROIDTOWN_TKBD>", "/ /").replace("<DROIDTOWN_TKBD>", "/")
        inputDICT["result_segmentation"] = tmpSTR
        return inputDICT

    def _posShift(self, posLIST):
        for i in range (0, len(posLIST)):
            if len(posLIST[i]) == 1:
                pass
            else:
                for pat in self.shiftRule:
                    shiftLIST = [(g.start(), g.end(), g.group(0)) for g in reversed(list(pat[0].finditer(posLIST[i])))]
                    for s in shiftLIST:
                        adjustedSTR = s[2]
                        for adjust_s in pat[1]:
                            adjustedSTR = adjustedSTR.replace(adjust_s, pat[2][pat[1].index(adjust_s)])
                        posLIST[i] = "{}{}{}".format(posLIST[i][:s[0]], adjustedSTR, posLIST[i][s[1]:])
        return posLIST

    def _pos2Seg(self, posLIST):
        resultSTR = ""
        for s in posLIST:
            resultSTR = resultSTR + re.sub(self.purgePat, "╱", s)
        return resultSTR

    def parse(self, inputSTR, level="lv2", userDefinedDictFILE=None, convert=None):
        for i in self.legacyLIST[0]:
            inputSTR = inputSTR.replace(i, self.legacyLIST[1][self.legacyLIST[0].index(i)])

        if level=="lv3":
            tgLV = "lv3"
            level = "lv2"
            if convert == None:
                convert = "TL"
            else:
                if convert.upper() in ("TL", "POJ", "WORD"):
                    convert = convert.upper()
                else:
                    raise
        else:
            tgLV = level

        if platform.system() == "Windows":
            self.TaigiDictFILE = tempfile.NamedTemporaryFile(mode="w+", delete=False)
        else:
            self.TaigiDictFILE = tempfile.NamedTemporaryFile(mode="w+")

        self.userDefinedDICT = self.defaultDICT
        if userDefinedDictFILE == None:
            pass
        else:
            with open(userDefinedDictFILE, encoding="utf-8") as f:
                userDefinedDICT = json.load(f)
            for k in userDefinedDICT.keys():
                try:
                    tmpLIST = userDefinedDICT[k]
                    for POS in self.defaultDICT.keys():
                        self.defaultDICT[POS] = list(set(self.defaultDICT[POS])-set(tmpLIST))
                    if k in self.userDefinedDICT.keys():
                        tmpLIST.extend(self.userDefinedDICT[k])
                    tmpLIST = list(set(tmpLIST))
                    self.userDefinedDICT[k].extend(tmpLIST)
                except KeyError:
                    self.userDefinedDICT[k] = tmpLIST

        #<利用 Articut 建立人名字典>
        checkingPersonDICT = self.articut.parse(inputSTR, level="lv1")
        personLIST = [p[-1] for p in [e[-1] for e in self.articut.getPersonLIST(checkingPersonDICT,  includePronounBOOL=False) if e != []] if p!=[]]
        if personLIST != []:
            self.userDefinedDICT["ENTITY_person"] = [p for p in personLIST if p[0] not in "伊毋" and p[-1] not in "舅叔嬸嫂婆爺爹娘父公爸母某翁姊姐妹兄弟字門梯鄉塗"]

        #</利用 Articut 建立人名字典>

        json.dump(self.userDefinedDICT, self.TaigiDictFILE)
        self.TaigiDictFILE.flush()

        self._mixedInputDetector(inputSTR)
        articutResultDICT = self.articut.parse(inputSTR, level=level, userDefinedDictFILE=self.TaigiDictFILE.name)
        articutResultDICT = self._spaceWalker(articutResultDICT)
        POScandidateLIST = []
        for tkn in articutResultDICT["result_segmentation"].split("/"):
            for k in self.userDefinedDICT.keys():
                if tkn in self.userDefinedDICT[k]:
                    POScandidateLIST.append(("<UserDefined>{}</UserDefined>".format(tkn), "<{0}>{1}</{0}>".format(k, tkn)))

        for i, s in enumerate(articutResultDICT["result_pos"]):
            for p in POScandidateLIST:
                articutResultDICT["result_pos"][i] = articutResultDICT["result_pos"][i].replace(p[0],p[1])
        print("src", articutResultDICT["result_pos"])
        articutResultDICT["result_pos"] = self._posShift(articutResultDICT["result_pos"])
        articutResultDICT["result_obj"] = self._pos2Obj(articutResultDICT["result_pos"])
        articutResultDICT["result_segmentation"] = self._pos2Seg(articutResultDICT["result_pos"])

        if tgLV in ("lv1", "lv2"):
            return articutResultDICT
        elif tgLV == "lv3":
            resultDICT = {"person": self.articut.getPersonLIST(articutResultDICT),
                          #"event": articutResultDICT["event"],
                          "time": self.articut.getTimeLIST(articutResultDICT),
                          "site": self.articut.getLocationStemLIST(articutResultDICT),
                          "entity":  self.articut.getNounStemLIST(articutResultDICT),
                          #"number": articutResultDICT["number"],
                          #"user_defined": articutResultDICT["user_defined"],
                          "utterance": [],
                          #"input": articutResultDICT["input"],
                          #"unit": articutResultDICT["unit"],
                          "exec_time": articutResultDICT["exec_time"],
                          "level": "lv3",
                          "version": articutResultDICT["version"],
                          "status": articutResultDICT["status"],
                          "msg": articutResultDICT["msg"],
                          "word_count_balance": articutResultDICT["word_count_balance"],
                          }
            # 呼叫一個 converter，把 resultDICT["result_obj"] 裡的詞彙一個一個轉成拼音。
            if convert == "TL":
                resultLIST = self._2TL(articutResultDICT["result_obj"])
            #elif convert == "POJ":
                #resultLIST = self._2POJ(articutResultDICT["result_obj"])
            #else: #convert == "WORD":
                #resultLIST = self._2Word(articutResultDICT["result_obj"])
            resultDICT["utterance"] = "╱".join(resultLIST)
            return resultDICT



if __name__ == "__main__":
    try:
        with open("../account.info", encoding="utf-8") as jF:
            accountDICT = json.load(jF)
    except:
        accountDICT = {"username":"", "apikey":""}

    accountDICT = {"username":accountDICT["username"], "apikey":accountDICT["apikey"]}
    articutTaigi = ArticutTG(username=accountDICT["username"], apikey=accountDICT["apikey"])
    #台語漢字 CWS/POS TEST
    inputSTR = "你ē-sái請ta̍k-ke提供字句hō͘你做這個試驗。"
    inputSTR = "跋倒, 佮意"
    inputSTR = "伊誠𠢕激五仁，激甲逐家笑咍咍".replace("。", "")

    inputLIST = [
        #"你愛有出脫人才會看你有",
        #"李家明仔載欲來捾定，咱著辦腥臊請人",
        #"雖然我佮恁阿爸平歲，毋過論輩無論歲，咱算仝沿的，叫我阿兄就好",
        #"借問一下，文化路佇佗位？",
        #"車斗有張升降尾門，較好起落貨",
        #"一人才分一疕仔，連楔喙齒縫都無夠",
        #"錢大百，人落肉",
        #"時機䆀䆀，我的錢水有較乏",
        #"原來你就是王董的，失敬，失敬！",
        #"伊生做肥軟仔肥軟，看著蓋古錐",

        "阮先行，恁押後",

        "張總的頂擺出張，去巡視海外的工場，佇遐蹛個外月",

        "這張圖真媠，我欲描一張起來",
        "喙共弓開才會當灌藥仔",
        "伊人誠䆀猴",
        "一日到暗喈無錢",
        "這領衫我看袂過目",
        "這領衫有三鈕鈕仔",
        "拄著好時運",
        "廟仔有童乩咧跳童",
        "辭典是真重要的工具冊",
        "做人的囝兒毋通予爸母操心",
        "兩錢金仔",
        "伊咧讀冊",
        "伊這款做法手路傷粗啦",
        "做予好勢",
        "做散工的人趁的錢袂齊勻",
        "這種餅哪會做這形的",
        "共囡仔唔予伊睏",
        "一門大炮",
        "伊上要緊彼隻狗",
        "伊佇咧睏",
        "請你評看啥人較有理",
        "伊的人真笑詼",
        "來者是客",
        "食美國仙丹的副作用是面會圓圓",
        "我的目尾開始有皺痕矣",
        "意氣投合",
        "這片山坪種足濟茶欉",
        "氣力有夠",
        "這逐家嘛看過",
        "拑牆壁",
        "你無證據哪會當誣賴人",
        "興風作浪",
        "魚肉鄉民",
        "伊頂日仔才無去的",
        "這个牌子的產品真有信用",
        "市場外口有人咧拚俗貨",
        "代誌按呢一直吊佇半空中嘛毋是辦法",
        "枵雞無畏箠",
        "你明仔載去揣看有師傅會當來掠漏無？",
        "鐘聲真響亮",
        "往西爿行去",
        "攑椅頭仔去外口坐較秋凊",
        "門關無密",
        "大自然實在真奇妙",
        "你這個月的開銷有較濟",
        "這領衫皺去矣",
        "你毋通放蕩過一生",
        "你哪會使攑牛捽仔咧捽囡仔？",
        "這款索仔較粗勇",
        "激一个氣",
        "我已經想無閣較好的計策矣！",
        "喙焦喉渴",

        "現流仔上鮮",
        "七分酒對三分水上拄好",
        "兄弟攏分散了了矣",

        "斟酌觀察",
        "你的面看起來一點仔血色都無",
        "拹鐵釘仔",
        "原來這層代誌是你咧變鬼",
        "較加嘛會駐水",
        "搦著證據",
        "一橛甘蔗",
        "想袂到伊會為著利益來反背眾人",
        "頭毛鬖鬖",
        "伊的身體有夠勇",
        "倩一陣弄龍的來鬧熱",
        "我致這个症頭已經幾若年矣",
        "電影看煞才來去食飯",
        "伊退休了後就無插代誌矣",
        "囡仔出癖的時陣毋通共伊𤆬出去",
        "總統委任伊做大使派往聯合國",
        "伊堅持無欲做人的接跤的",
        "伊早頓攏嘛烏白食",
        "謼！閣來矣！",
        "偷食野味",
        "欲做伙來去踩街無？",
        "出好囝孫",
        "孤鳥插人群",
        "伊走無去矣",
        "啥物人佇遐咧唱歌？",
        "我欲食糜",
        "這粒錶仔定去矣",
        "攏是伊佇遐咧挲圓捏扁",
        "伊的行為引起人的注目",
        "水蝕落去矣",
        "君子務本",
        "你實在足挐的！",
        "伊的名聲真響",
        "屎瞪袂出來",
        "伊獸醫系畢業了後就開始做獸醫",
        "料想袂到",
        "這个囡仔號名未？",
        "覺悟著過去做了毋著",
        "伊透底毋捌出國",
        "伊共代誌凊彩戽戽咧就準拄好矣",
        "這盤芥藍仔菜有夠柯",
        "伊是阮細的",
        "你穿的衫是羊毛的",
        "到今你才知！",
        "伊看著蛇會掣",
        "草蓬蓬生",
        "阮的厝邊攏誠好鬥陣",
        "這是在地的果子",
        "伊看起來加較少年",
        "三年仔有十班",
        "錢予賊仔偷提去矣！",
        "家家戶戶",
        "才號有好名",
        "伊的目睭真尖",
        "你睏了有飽眠無？",
        "你是趖去佗位？",
        "對遮拋近路較緊",
        "伊佇公所食頭路",
        "伊是教會的老姑娘",
        "硞著頭額",
        "較成物的留咧",
        "西醫的效果比中醫較緊",
        "看鬧熱的人相挨相𤲍",
        "物件揀好去揣店員結數",
        "兩个好朋友哪會相拍？",
        "我已經泡一杯厚茶欲予你解酒",
        "伊做人真澀",
        "日本話我普普仔聽有",
        "二品碗公",
        "害矣啦！代誌煏空矣啦！",
        "疔仔的膿泏出來矣",
        "毋通忤逆序大人",
        "粒仔咧流湯",
        "回心轉意",
        "這款花草較清較好看",
        "股市崩盤",
        "作田人放伴作穡",
        "這擺公司虧損真嚴重",
        "電線相拍電",
        "我心肝內感覺對伊真袂得過",
        "伊有敲電話來請假",
        "我的代誌免你插",
        "褲袋仔袋磅子",
        "這个囡仔做代誌誠規矩",
        "期待再相會",
        "我有一雙大跤胴",
        "頭毛真旺",
        "下早仔水氣真重",
        "糝一寡糖",
        "伊閣咧假痟矣",
        "這領膨紗衫是阿媽共你刺的",
        "毒品害伊行上絕路",
        "臺北車頭內面五路的人攏有",
        "咱毋通濫糝共人批評",
        "馬耳東風",
        "阮某轉去外家矣",
        "剝筍仔殼",
        "這个人看著戇直戇直",
        "我共你當做是上好的朋友",
        "阮老母咧替人騙囡仔",
        "求神明扶持",
        "豬母帶膭",
        "伊的物件交代我保管",
        "這港水泉的水誠甘",
        "細粒子的較𠢕囥歲",
        "掖草仔子",
        "應喙應舌",
        "鬼頭鬼腦",
        "一欉成人懸的樹仔",
        "伊去做工矣",
        "你袂曉寫的題目就先勾起來",
        "索仔若拍死結就真僫敨開",
        "有其父必有其子",
        "你順路送伊轉去",
        "起跤動手",
        "伊的目睭誠利",
        "生活真穩定",
        "往過的人晏報戶口是誠四常的代誌",
        "論輩無論歲",
        "你𣁳一碗湯予我",
        "吊橋行著會㽎",
        "請你有閒來阮遐𨑨迌",
        "伊收跤洗手誠濟年矣",
        "伊猶原佇遐咧等你",
        "佇社會上走跳",
        "你哪會遐狼毒？",
        "彼个人的心肝誠惡毒",
        "空喙咧吐肉箭矣",
        "海水漲起來矣",
        "伊的作為予人誠欣賞",
        "大港無崁蓋",
        "赦你無罪",
        "這間冊店有賣印色",
        "伊共索仔翸斷去矣",
        "阿姊攑花仔傘共彼个阿婆遮日",
        "伊的鼻真利",
        "無證據毋通佇遐吐憐涎",
        "巷仔內有一間板仔店",
        "結婚進前",
        "臭柑排店面",
        "趕緊共你跤底的塗沙刮刮咧！",
        "大量生產才算會和",
        "共草仔耙倚來",
        "演員的替身",
        "鬚聳目降",
        "遮的物件緊送去工場予",
        "是按怎這件代誌到這馬猶未條直？",
        "我今仔日是專工欲來佮你相辭的",
        "伊的心情誠䆀",
        "人若大到在矣就免食轉骨的補藥矣",
        "瘦田歹種作",
        "慶祝生日",
        "你去共茶盤洗清氣",
        "抉紅毛塗",
        "伊若無錢就變無魍矣！",
        "這塊肉真肥",
        "跂較懸咧",
        "妖魔鬼怪",
        "將來會發生啥代誌無人知",
        "伊扞一間礦業公司",
        "有人駐死佇水底",
        "你毋通為著人有好的物件就赤目",
        "伊生做足大漢",
        "金光閃閃",
        "款厝內毋是干焦查某人才會當做的工課",
        "伊閣咧想伊的未婚妻矣",
        "伊會當躘真懸",
        "伊毋是簡單的人物",
        "恁兩人的結合是我上大的願望",
        "伊的車門予人挵一㧌",
        "你共遮的物件囥入去觳仔內底",
        "有家有後",
        "漚柑鋪籠面",
        "臺灣囡仔歌算是唸謠",
        "彼个人按怎叫都叫袂振動",
        "時間無早矣",
        "本來就是按呢嘛！",
        "你參伊去",
        "一目甘蔗",
        "這塊布較結較袂破",
        "伊用草做一隻狗",
        "桌頂全坱埃",
        "哈哈大笑",
        "佇基隆有一間服侍老大公的廟",
        "逐家攏看現現",
        "有人咧揤電鈴",
        "你啥物時陣欲倒去？",
        "伊堅持欲繼續拍拚落去",
        "兩个相接跤來",
        "啥人叫你大主大意做這件代誌？",
        "一項代誌",
        "彼間麵店仔欲褪人",
        "看人的目色過日子",
        "這隻船食水偌深？",
        "塗跤陷入去",
        "我無佮意伊做代誌的方式",
        "你予我考慮一下",
        "一子弓蕉",
        "共錢筒仔破開",
        "這擺的代誌我嘛無步矣",
        "我最近較閒",
        "電影已經收場矣",
        "跩來跩去",
        "閃爍的天星",
        "一下仔久就好矣",
        "伊真𠢕吮食",
        "正月初二查某囝轉外家做客",
        "伊予警察掜留佇警察局",
        "你按呢做毋驚會夭壽！",
        "棉被先捲起來才收入去袋仔內",
        "毋是每一个人攏適合食素食",
        "世間上有真濟代誌是袂按算的",
        "伊對你有情意",
        "雞髻大塊看起來真威風",
        "兩个人的感情真好",
        "這兩種有啥物精差？",
        "孤𣮈絕種",
        "外口較涼",
        "今攏害了了矣！",
        "今年的王梨失收",
        "提去外口予日頭爁一下",
        "拜託你放手",
        "心存善念",
        "這塊肉真韌",
        "這條錢是伊過手的",
        "飼伊成人",
        "阿英明仔載欲轉後頭",
        "心涼脾土開",
        "用鏨仔雕刻一身佛像",
        "坐予好勢",
        "節省時間",
        "這句話是伊提頭的",
        "壁落漆",
        "伊寫字、食飯攏用倒手",
        "做序細的無應該佮序大人應喙應舌",
        "排做三排",
        "這件代誌是你該做的",
        "閹過的雞公飼較會大",
        "兩爿佇咧對削",
        "沿路抾客",
        "牽牛去食草",
        "扯一个結",
        "糜煮了傷漖",
        "伊真五仁",
        "修剪樹枝",
        "涵空無敨",
        "一爿西瓜",
        "我彼本冊你敢有看見？",
        "伊的手頭真重",
        "這是阮阿母的手路菜",
        "大不了予人罵罵咧爾爾",
        "天光矣",
        "伊放聲欲予你好看",
        "專制政府刑罰政治犯的手段真粗殘",
        "你緊來共我鬥跤手",
        "一大捾的荔枝",
        "伊佇法院共人通譯",
        "死都死囉！毋通閣來交纏",
        "我借伊一本冊",
        "伊拄才對外口轉來",
        "打探消息",
        "昨暝狗母毋知按怎一直吹狗螺",
        "這幅圖我感覺無啥物特別",
        "來來來！逐家上桌食飯",
        "西藥食了較散",
        "你千萬毋通誤會",
        "注大筒的",
        "伊一个癖性佮人無仝款",
        "物件囥佇桌頂",
        "伊對逐項代誌攏無興頭",
        "斷了批信",
        "阮囝已經會曉家己扒飯矣",
        "你毋通起歹心共伊計算",
        "這堵壁缺兩隙",
        "好歇工矣",
        "彼个所在誠遠",
        "你欲坐碌硞馬無？",
        "用鐵枝拄門",
        "伊踏著黃金矣",
        "單槍匹馬",
        "伊毋願做人的細姨",
        "予海湧𩛩去",
        "伊的人較土",
        "雞僆仔肉較幼",
        "你臆了真準",
        "伊生做較細漢",
        "恁毋通起跤動手",
        "兩个人𢯾做伙",
        "飯食了才食果子",
        "我下晡會共錢匯入去你的戶頭",
        "天篷陷落來",
        "伊真厚話屎",
        "逐个囡仔攏是爸母的心肝仔寶貝",
        "伊的消息誠靈通",
        "火舌爁一下",
        "伊去予警察召去問口供",
        "伊的思想誠保守",
        "這間公司的財務需要整頓一下",
        "咱共灶跤清清咧",
        "花是你送的乎？免歹勢啦！",
        "會䠡袂爬",
        "王侯將相",
        "鹹水魚若是現流仔加足貴的",
        "三穗番麥",
        "爸仔囝拆開欲十年矣",
        "彼个人的心腸真䆀",
        "囡仔身軀洗好糝一屑仔痱仔粉較焦鬆",
        "人情世事",
        "伊真有喙水",
        "定定用話共我洗",
        "去山頂隱居",
        "伊彼支鼻真媠",
        "伊共甘蔗遏做兩節",
        "陳的佮王的咧加話",
        "稻仔抽長結穗矣",
        "一矸米酒",
        "伊做生理真殺",
        "這齣戲做透矣",
        "伊閣佇遐佯痟矣",
        "伊一直揣機會欲報鳥鼠仔冤",
        "拳頭拇對胸坎貫落去",
        "有的跤踏車倒踏就會停",
        "啥物人接你的缺？",
        "伊的勢力誠大",
        "魚仔瀳倚來",
        "阮阿母較早專門咧共人抾囡仔",
        "伊將我放袂記得矣",
        "開光點眼",
        "我的工課足濟的",
        "這馬的野球攏真注重戰術",
        "蓋世奇才",
        "謝天謝地",
        "共糞埽吸起來",
        "用話叉人",
        "昨暗伊無轉來睏",
        "一條新聞",
        "伊連鞭就會出師矣！",
        "伊是阮的親生老爸",
        "伊規工攏佇外口拜訪客戶",
        "在你去啦！",
        "你毋通予人當做盼仔",
        "三鉼鐵鉼",
        "做人毋通遐歹心",
        "伊是阮兄哥",
        "伊是駐水死的",
        "拋魚著趁流水",
        "這本冊你共我接過去",
        "這款冤枉錢你曷開會落去！",
        "無暝無日",
        "伊的人範袂䆀",
        "伊志願來的",
        "我猶未食飯",
        "你毋通空喙哺舌誣賴別人",
        "物件予人勍去矣！",
        "伊是佇昨昏頂半暝過身去的",
        "老母破病了後到今攏無較好",
        "哪未轉來？",
        "到底你的意願是按怎？",
        "敢閣有另外的人欲來？",
        "我的房內全是花的芳味",
        "伊的頭毛軟㽎㽎",
        "你毋通走去遐共人鬧台",
        "囡仔騙袂恬！",
        "昨暗我夢著中大獎",
        "跋落萬丈深坑",
        "三頓攏食外口",
        "恁兜是蹛佇佗位？",
        "相爭做乞食頭",
        "緊去予醫生看",
        "嬈花查某",
        "落雨天無法度曝粟",
        "共棉被舒舒咧",
        "尻川斗翹翹",
        "我會真毋甘",
        "這層代誌你會當請伊代辦",
        "伊按呢做是欲做人情予你",
        "嬰仔尻川𩛩著",
        "佇繡房內刺花繡針黹",
        "水捙倒去矣",
        "頭抽豆油",
        "蛟龍泅魚池",
        "伊定定用暗步欲陷害人",
        "聲音哪會攏恬去矣？",
        "金枝玉葉",
        "伊的面有一疧",
        "我共面巾溼予伊澹",
        "五十外歲",
        "你敢知影伊叫做啥物名？",
        "曲跤撚喙鬚",
        "請朋友看電影",
        "一領破衫㧣一冬",
        "你按呢死坐活食敢是辦法？",
        "烏骨雞的市價比肉雞仔較好",
        "逐家對伊的印象真好",
        "伊又閣咧起狂矣",
        "伊因為帶身命才會攏無咧上班",
        "伊大我一輩",
        "象是陸地上上大隻的動物",
        "趁放假去𨑨迌會當改換心情",
        "大本蕹菜",
        "隱痀的交侗戇",
        "你去攑沙耙共跳遠場地整予平",
        "用紙篋仔貯糖仔餅",
        "的交陪誠深",
        "你對我有誤會",
        "真有體面",
        "你是肯抑毋肯？",
        "伊的跤真臭",
        "囡仔好育飼",
        "伊去予人修理",
        "賣摵仔麵的用麵摵仔摵麵",
        "會計師明仔載欲來阮公司查數",
        "彼个人有夠𡳞蔓",
        "老爸是有錢人",
        "伊閣咧發輦矣！",
        "你毋通拍破人的飯碗",
        "檨仔切片烘予堅乾做檨仔乾",
        "臺灣的溪水攏是汫水",
        "伊是這角勢的角頭",
        "代誌猶未定著",
        "老牌歌星",
        "伊飼的雞仔攏著災死了了",
        "毋知咧無閒啥物",
        "這塊布的色緻真媠",
        "這領衫上適合你來穿",
        "尪架桌發爐",
        "天頂攏無雲",
        "拋磚引玉",
        "甍予你倒",
        "阮少爺對阮這寡下跤手人攏真好",
        "在座的人",
        "隨身行李",
        "鳥仔有翼才會飛",
        "今仔日欲搬啥物戲齣？",
        "汗㴙㴙滴",
        "火化去矣！",
        "禮拜咱才做伙來去看電影",
        "伊是分的",
        "鬥陣來去",
        "提針來紩衫",
        "恁查某囝敢做人矣？",
        "姑表相伨",
        "慢牛厚屎尿",
        "挽瓜揫藤",
        "戲院門口人插插插",
        "彼个人足屎桶",
        "伊會共人食倯",
        "孤鳥插人群",
        "彼隻船仔沕落去水底矣",
        "咱兄弟姊妹就像仝一條水脈流出來的啦",
        "囡仔上驚注射",
        "頭毛熁著火就虯去",
        "提出來予你鼻芳",
        "我的冊借人矣",
        "這塊枋一寸厚",
        "這馬真少人用柴頭咧燃火矣",
        "伊對喙就罵",
        "伊對食這項真甘開",
        "你號做啥物名？",
        "伊自做生理到今一直咧塌本",
        "伊較佮意淺色的衫",
        "今仔日伊閣來矣",
        "身軀洗了隨出去弄風會去寒著",
        "你足巧的呢！",
        "金錢毋是萬能的",
        "目睭澀澀",
        "蝦蛄頭食起來無較輸龍蝦",
        "伊真𠢕佮人捙盤",
        "伊決定欲辭職矣",
        "伊確實是一个好人",
        "伊決心欲拍拚讀冊",
        "我用人格共你保證",
        "是啥物人放臭屁？",
        "伊看別人無上目",
        "伊自來就毋捌破病",
        "提石頭共伊搩落去",
        "藥仔挽會行上要緊",
        "阮囝滿三歲矣",
        "毋通破壞人的感情",
        "兩鬢如霜",
        "熱鼎炒菜",
        "囡仔的成就是爸母的驕傲",
        "隔壁的地界一直楦過來",
        "既然如此",
        "濟牛踏無糞",
        "目睭褫開",
        "爽啦！我著頭獎矣！",
        "伊看著真疲勞",
        "伊生做真大漢",
        "藥仔食了有較差無？",
        "塗跤先苴報紙才開始油漆",
        "提供證明文件",
        "目睭瞪大蕊",
        "今年是一个好年冬",
        "丹田無力",
        "伊無一定會來",
        "無趨袂瀉水",
        "你的人面較熟",
        "三條茄毋值一粒蟯",
        "無大無細",
        "一時的失敗嘛毋通失志",
        "罕罕仔才啉一擺酒",
        "佮伊錚落去",
        "便有錢就開了了",
        "櫻花的樹身真金滑",
        "鴨鵤袂生卵",
        "彼間百年老店到今猶是第三代的老頭家咧徛台扞店",
        "鬱死人的才調",
        "雞屎運咧敨",
        "獻敬神明",
        "飼囝真辛苦",
        "伊去予車挵一下著重傷",
        "共伊放袂記",
        "啉一杯茶",
        "你對這个方向直直行就到矣",
        "股票上市",
        "一肢跤指頭仔",
        "祝你一路順風",
        "食飽桌頂無拭會唌虼蚻來",
        "伊閣咧共我供體矣",
        "一打汽水",
        "寬寬仔是",
        "我袂記得伊號做啥物名",
        "我毋捌跍咧食飯",
        "雞仔生雞𧉟真普遍",
        "伊這擺的表現真落氣",
        "腹肚脹起來",
        "原早的路無蓋大條",
        "伊徛對面共我擛手",
        "好天的時阮欲來去山",
        "我來拍頭陣",
        "大貨車敢會當入去巷仔底落貨？",
        "貓仔上佮意臭臊的",
        "風流人物",
        "歇睏日伊常在𤆬一家伙仔去郊外𨑨迌",
        "哭爸！我袂記得紮錢！",
        "頂禮拜阮一陣人上山去看風景",
        "明仔載欲報數",
        "厝內真驚人",
        "徛佇籠床邊熁燒",
        "伊做代誌攏會留一寡屎尾予別人替伊處理",
        "插春仔花",
        "這隻膨椅已經窞肚矣",
        "伊無因為我生做較歹看面就棄嫌我",
        "提出較好的條件對方就會投降",
        "等戲煞鼓咱來去食宵夜",
        "鰇魚烘無偌久就會蔫",
        "伊無細膩去挵著電火柱",
        "我看著伊就刺疫",
        "萬項代誌攏有前因後果",
        "伊徛佇外口颺風",
        "這個月無來洗",
        "風流才子",
        "路口彼間藥局生理真好",
        "伊生做真好看",
        "提起告訴",
        "一鈕仔囝",
        "向望你會當好好仔做人",
        "火化去矣",
        "稻仔佈了傷櫳",
        "加官晉祿",
        "警方咧調查死者敢有佮人結怨",
        "我對籃球無興趣",
        "細條巷仔",
        "我生理失敗的時佳哉有伊共我打扎",
        "我都無錢矣你……",
        "囡仔的𨑨迌物百百款",
        "收疕矣",
        "火咧湠真緊",
        "煞著頂腹蓋",
        "這件代誌交予你來摠",
        "規日神神",
        "你毋通遐八珍",
        "伊跍佇門口看過路人",
        "遮的柳丁會使提去散賣",
        "爸母飼囝真辛苦",
        "伊失蹤成月日矣",
        "你電話幾番？",
        "死鴨仔硬喙桮",
        "過面矣",
        "工課放咧走去踅街",
        "阿祖較早做過藝旦",
        "三身娘仔",
        "伊佇戰爭的時著銃",
        "兜的家伙攏予伊敗了了矣",
        "我佮伊定定相扴",
        "今年聯考英文的題目真簡單",
        "伊佇公家機關服務",
        "伊攏交結一寡做官的",
        "你去叫彼个走桌的閣捾兩罐麥仔酒來！",
        "大牛惜力",
        "你是偏偏欲佮我做對是無？",
        "酸的物件我較無銷",
        "食老耳空重",
        "臺灣的本土語言毋知閣會當保存偌久？",
        "伊做人真現實",
        "甜粿炊無透",
        "央人寫批",
        "無把握的代誌毋通做",
        "老師咧改簿仔",
        "哭枵！無紮雨傘煞咧落雨",
        "這塊眠床枋足𠕇的",
        "伊真𠢕經絲",
        "沙龍巴斯貼久嘛會起藥蛆",
        "戲棚跤徛久就是你的",
        "彼幅圖真歹看",
        "你哪毋去食飯？",
        "伊不時嘛咧讀冊",
        "這件代誌請你共我運動一下",
        "目空真深",
        "我無欲去啦！",
        "共藥丸磨做藥粉",
        "伊予頭家冰起來",
        "咱做序細毋通予序大人操煩",
        "我來卜一下仔卦咧",
        "伊是阮牽的",
        "邀請伊來參加",
        "一支鎖匙",
        "真實的感覺",
        "違約交割",
        "兩人伨頭搬戲",
        "阮店賣的攏是高級貨",
        "用攄仔剃頭真方便",
        "佇塗跤畫格仔",
        "我共你保證伊開的支票袂跳票",
        "胡蠅颺颺飛",
        "伊牽抾我趁足濟錢",
        "坐倚來",
        "看起來伊猶毋知",
        "天貓霧仔光伊就起來矣",
        "伊足得人惜的",
        "予錢鼠咬破布袋",
        "順風捒倒牆",
        "這件代誌我願意做",
        "彼件代誌我干焦略仔知爾爾",
        "今仔日天氣真翕",
        "彼个少年家真好差教",
        "烏仔魚搢水",
        "現挽現食",
        "一屑仔無夠通楔喙齒縫啦！",
        "這馬足少人咧翕烏白的相片矣",
        "伊搭胸坎保證無問題",
        "頭殼尖尖做錢貫",
        "梅仔蜜了有透",
        "你腹內火氣傷大",
        "有一个查某囡仔按對面行過來",
        "遠親不如近鄰",
        "差無偌濟",
        "你是家己開業抑是予人倩？",
        "伊規工攏佇厝裡無出去",
        "嘉南大圳",
        "這聲苦矣！",
        "按呢敢會祭孤得？",
        "咱雙頭攏來去揣看覓",
        "予人屧手縫都無夠",
        "被囊剝起來洗",
        "你傷倖囡仔",
        "我恁祖公",
        "春夏之交",
        "伊昨昏三更半暝才轉來",
        "手足擽的",
        "伊共兩本簿仔敆做伙",
        "你下的願敢有應效？",
        "倚樣做衫",
        "了錢生理無人做",
        "伊咧唱歌會走音",
        "一牢雞牢",
        "你這過的成績有淡薄仔退步",
        "衫仔擢擢咧",
        "意氣用事",
        "塗豆仁粩",
        "阿玉已經做人矣",
        "伊食錢的代誌煏空矣",
        "奅姼仔伊有一套",
        "這个囡仔真用功",
        "捀一盤菜",
        "今仔日推了有夠飽的",
        "一篋仔餅",
        "伊生做真䆀",
        "狂風大作",
        "恁是咧起痟呢？遐爾仔寒閣欲去泅水",
        "我欲去北港媽進香",
        "阿爸睏醒矣",
        "伊最近捷捷來",
        "物件毋通落勾",
        "伊佮老爸生做誠成",
        "一戶人家",
        "伊有六尺懸",
        "伊為著家己的利益出賣朋友",
        "若按呢愈好",
        "伊共這塊肥豬肉提去炸豬油",
        "量其約仔",
        "光復失土",
        "手予蠓仔叮一模",
        "絲番薯葉",
        "向逐家謝罪",
        "新正年頭",
        "自我介紹",
        "伊對人真誠懇",
        "這塊布布目較疏",
        "我看著有人佇水底沐沐泅",
        "閘佇半路拍人",
        "請你名簽蹛遮",
        "大孫捀斗",
        "你千萬毋通閣行歹路",
        "以早的人攏提豆餅咧飼豬",
        "你毋通閣來膏膏纏",
        "伊今仔日會做這款代誌攏是予人煽動的",
        "壁有一位噗起來矣",
        "這本課本有十二課",
        "樹尾無風袂搖",
        "伊哪會遐才情",
        "伊駛車去軋著人",
        "伊病一下真食力",
        "這條代誌我聽了誠憤慨",
        "你哪會遮爾跤梢？連這曷袂曉",
        "今仔日下晡的天氣真秋凊",
        "年節的民俗",
        "我共你撫撫咧！",
        "目睭噗噗",
        "這味藥仔是推會行抑推袂行？",
        "將心比心",
        "夭壽！阮這條巷仔昨昏又閣著賊偷矣",
        "伊攏總生六个後生",
        "明仔早起我欲佮阮阿公去運動",
        "伊真𠢕軁",
        "我看阿忠輸面較大",
        "好酒沉甕底",
        "你對這件代誌有啥物感想？",
        "你喊啥物名？",
        "兩捻龍眼",
        "垂肩的人穿衫較無好看",
        "到位矣",
        "食老面皺皺",
        "合掌參拜",
        "伊退休了後生活誠逍遙",
        "硬骨的囡仔攏較毋認輸",
        "興衰有時",
        "阮的工頭看起來猶閣真少年",
        "這馬我才知影伊是騙我的",
        "女扮男裝",
        "頭毛染色",
        "伊閣鬧代誌矣",
        "警察指揮交通",
        "你有看著我的數單無？",
        "共屜仔挩開",
        "現此時的人攏較會曉享受",
        "阮翁仔某頂下歲",
        "伊去予滾水燙著",
        "想袂到會變做這个局面！",
        "一年半載",
        "野生動物",
        "伊供出真濟人",
        "有代誌才呼我",
        "阮先生娘生做真媠",
        "定定食菜較袂高血壓",
        "予風尾掃著",
        "用別人的拳頭拇舂石獅",
        "你欲揣的人就是我",
        "錶仔定去袂行矣",
        "濺蠓仔水",
        "伊是阮祧仔內的",
        "逐家做伙來做功德",
        "路邊擔仔的物件較俗",
        "阮序大人攏是誠理解的人",
        "用手比較緊",
        "桌布澹澹𩛩咧會臭臭",
        "伊食重鹹",
        "伊的頭去挵著桌角",
        "伊毋是刁意故的",
        "彼隻狗仔咧𪁎矣",
        "火車閣十分鐘就會到位矣",
        "人民捙倒獨裁者的銅像",
        "咱下昏來去踅夜市",
        "我感覺伊真顧人怨",
        "人𤲍人",
        "你這个卑鄙的小人",
        "我毋捌出國過",
        "唉！真可惜",
        "兩隻牛咧相觸",
        "這水的塗豆真飽仁",
        "明仔載我會坐客運轉去",
        "一葩電火",
        "我功課若寫好就會使去看電影矣",
        "讀國中彼當陣伊就帶痚呴",
        "哈！予我掠著矣",
        "食一頓飯",
        "伊做的彼件歹代誌早慢會破空",
        "心肝內感覺酸酸",
        "伊彼个人誠重錢",
        "軟塗深掘",
        "少年人往往攏較衝碰",
        "番薑仔醬",
        "用橐仔共葡萄套起來",
        "稻仔穗頕落去",
        "財產放予囝孫",
        "猛虎難敵猴群",
        "毋著啦！",
        "你就當做無伊的存在",
        "你誠敢呢！這款代誌你竟然做會出來！",
        "販貨去賣",
        "春天後母面",
        "我欲予伊歹看",
        "本錢真粗",
        "下暗欲來阮兜予阮請無？",
        "彼个物件限你明仔載中晝以前予我",
        "士農工商",
        "暝尾的時足寒的",
        "闊喙的食四方",
        "你緊共伊擋咧！",
        "此情此景",
        "中產階級",
        "小旦上𠢕共人使目尾",
        "伊走了真緊",
        "這个木匠做的木工袂䆀",
        "伊的一句話予我規个心頭挐絞絞",
        "草蓆仔頂的塗粉拭拭咧才去睏",
        "多謝你！",
        "頂日仔規家伙仔有來我遮",
        "欸，哪會按呢？",
        "以德報怨",
        "豬仔相經",
        "十全十美",
        "這有啥物路用？",
        "經營事業",
        "出頭損角",
        "這領衫較暗色",
        "用好紙褙",
        "布邊繐去矣",
        "青天白日",
        "山頂彼陣猴定定落山來損蕩人的果子園",
        "我佇臺灣出世的",
        "封頭壁會洩水",
        "家伙跋了了",
        "何方神聖",
        "伊相罵攏毋免掀戲文",
        "伊對我真好",
        "我做的敢有算額？",
        "彼个查某囡仔敢猶活會？",
        "頭家共伊漲懸價",
        "手不動三寶",
        "予人呸瀾",
        "昨昏佇會場遇著老朋友",
        "伊佇番薯園咧掘番薯",
        "盡人事順天意",
        "伊猶細漢",
        "尾溜翹起來",
        "我共你捋頭毛",
        "冇粟收入好米籮",
        "陰陽兩極",
        "頭毛菜誠輕秤",
        "金仔折現金",
        "我佮你差有一輪",
        "這間金仔店是阮遮上大間的",
        "食厚薰真傷肺管",
        "某偷咬雞仔伊敢毋知？",
        "伊的心肝足硬",
        "度看有發燒無？",
        "你真正有夠悾歁",
        "逐个人的興趣攏無款",
        "伊做人真虯",
        "新的公路欲開磅空對這粒山下跤迵過",
        "西北雨落袂過田岸",
        "這是啥人的主意？",
        "毋知伊的新頂司個性啥款？",
        "會曉煮雜菜麵的麵擔仔愈來愈少矣",
        "我會當幫助你的所在真有限",
        "藥膏抹落去粒仔就收喙矣",
        "閒閒罔出來行跤花",
        "一片枋仔",
        "成雙成對",
        "規嚾規黨",
        "你看我穿按呢敢好？",
        "動拳頭拇",
        "一𥐵醬菜",
        "我頂伊的缺",
        "規公司的代誌攏是伊咧摠頭",
        "工課僫做",
        "這是啥物物件？",
        "欱予伊倒",
        "這種漚色的衫無適合少年人穿",
        "定期存款",
        "阮兜的巷仔口有一間金紙店",
        "綴我來",
        "一串珠仔",
        "去共人客斟茶",
        "有教無類",
        "敢是欲落雨矣",
        "一棟樓仔厝",
        "我從到今毋捌看過遮爾仔㾀勢的查某",
        "花花世界",
        "合股做生理",
        "軍師獻計",
        "伊哪會蝹落去？緊共伊插起來",
        "對手誠弱",
        "天上聖母",
        "你今仔日欲出去𨑨迌乎？",
        "的生活真困難",
        "加減趁一寡仔外路仔來相添所費",
        "啉酒我無趣味",
        "恁新婦當時順月？",
        "花枝先剺花才落去炒",
        "清官難斷家務事",
        "伊面貓貓",
        "公親變事主",
        "錢算了花去",
        "我的代誌毋免你家婆",
        "伊生做吐目吐目",
        "修整路面",
        "你車駛這向敢著頭？",
        "石頭𠕇硞硞",
        "阮阿公較早佇人兜做長工",
        "伊跤手真緊",
        "用手出力共伊黜",
        "你去提凊飯來炒",
        "伊近來定定去拄著麻煩",
        "慈善事業",
        "心頭悶悶",
        "是啥物代誌予伊起毛䆀？",
        "大目新娘揣無灶",
        "開口借錢",
        "共烏枋的字擦擦咧",
        "腹腸狹的人較會排斥別人",
        "拆單欲去坐火車",
        "這款衫連鞭就退流行矣",
        "白頭偕老",
        "今仔日有一个和尚來遮化緣",
        "這粒楊桃有六捻",
    ]
    #inputLIST = ["地動發生到今(4/10)是第八工，砂卡礑步道猶是走揣的重點。今仔早重機具佇步道繼續挖，有揣著兩名死者，可能是姓游的爸爸和查某囝，佇這兩位死者的下跤閣挖著兩个死者，是相攬的姿勢。第三位可能是媽媽，而且佇身軀頂有揣著伊和三个囡仔的健保卡，另外佇咧暗頭仔也閣挖著一位死者，應該是上細漢的查某囝，若無意外，挖出來這五个人就是一家伙仔。",]
    #inputLIST = ["信義區",]
    for inputSTR in inputLIST:
        resultDICT = articutTaigi.parse(inputSTR, level="lv2")
        print("\n")
        pprint(resultDICT["result_pos"])
        pprint(resultDICT["result_segmentation"])
        print("=================================")

    #inputSTR = "阿明聽了，煞想著一个問題：「若準風颱嘛算是一種自然的現象，為啥物咱猶原愛驚惶伊？」老大人笑笑仔共伊講：「因為咱攏無了解風颱，所以才會感覺驚惶。」".replace("。", "")
    #resultDICT = articutTaigi.parse(inputSTR, level="lv2")
    #pprint(resultDICT)
    #<ENTITY_pronoun>[^<]+</ENTITY_pronoun>(<FUNC_inner>[^<]+</FUNC_inner>)?<ENTITY_noun>[^<]+</ENTITY_noun><DegreeP>[^<]+</DegreeP>


DT_ActionVerb = ["反輾轉",
                 "輾轉",
                 "提供",
                 "設計",
                 "欣賞",
                 "使用",
                 "來往",
                 "來臨",
                 "保存",
                 "保留",
                 "偷拈",
                 "偷聽",
                 "公佈",
                 "公演",
                 "冷凍",
                 "改變",
                 "改革",
                 "輕秤",
                 "咬岫",
                 "咬喙",
                 "變款",
                 "想欲",
                 "欲死",
                 "欲去",
                 "欲來",
                 "欲愛",
                 "啞口",
                 "喝枵",
                 "拋網",
                 "聯絡",
                 "著急",
                 "加捌",
                 "加入",
                 "加得",
                 "加添",
                 "加講話",
                 "受害",
                 "食食",
                 "懍場",
                 "吞忍",
                 "回絕",
                 "坐胎",
                 "外銷",
                 "內銷",
                 "守寡",
                 "就任",
                 "展伸",
                 "廢除",
                 "趕工",
                 "接跤",
                 "發燒",
                 "發酵",
                 "引起",
                 "起來",
                 "出來",
                 "出仕",
                 "出題",
                 "入來",
                 "害去",
                 "出去",
                 "傳出去",
                 "走出去",
                 "走袂離",
                 "走江湖",
                 "好食睏",
                 "燒好香",
                 "交落身",
                 "好離離",
                 "好離",
                 "離婚",
                 "出頭",
                 "出頭天",
                 "雨澹水滴",
                 "牽龜落湳",
                 "看破跤手",
                 "嫌東嫌西",
                 "看口得",
                 "看鬧熱",
                 "害人",
                 "唬人",
                 "罵人",
                 "享用",
                 "註冊",
                 "擺撥",
                 "滿意",
                 "報告",
                 "由在",
                 "嚇驚",
                 "摸飛",
                 "準備",
                 "放學",
                 "轉來",
                 "呷飯",
                 "食飯",
                 "表演",
                 "表現",
                 "放火",
                 "自首",
                 "耍歹",
                 "相見",
                 "餓死",
                 "難產",
                 "燒了了",
                 "主辦",
                 "止疼",
                 "熱著",
                 "分發",
                 "負擔",
                 "敬重",
                 "交纏",
                 "專門",
                 "慒心",
                 "衝過",
                 "受訓",
                 "食暗頓",
                 "曉",
                 "改薰",
                 "歹過日",
                 "打對折",
                 "揤牢",
                 "火大",
                 "出脫",
                 "倒數",
                 "比賽",
                 "充滿",
                 "完成",
                 "明呼",
                 "明唱",
                 "恭喜",
                 "體貼",
                 "情願",
                 "焦鍋",
                 "曝焦",
                 "收成",
                 "收入來",
                 "落種",
                 "參加",
                 "朗讀",
                 "讀冊",
                 "僫𤉙",
                 "落塗",
                 "落土",
                 "落軟",
                 "準煞",
                 "減講",
                 "代理",
                 "厚操煩",
                 "去了了",
                 "消災解厄",
                 "初見面",
                 "惜命命",
                 "枵過飢",
                 "倒轉來",
                 "趕轉去",
                 "準煞去",
                 "去倒害",
                 "吞吞吐吐",
                 "相挖空",
                 "大趁錢",
                 "大笑",
                 "大哭",
                 "培養",
                 "破去",
                 "過火",
                 "巴結",
                 "講出去",
                 "驚生份",
                 "驚一趒",
                 "關起來",
                 "出風頭",
                 "頓印仔",
                 "出國",
                 "保持",
                 "出在",
                 "拍結",
                 "拍算",
                 "拍拚",
                 "拍賣",
                 "拍電動",
                 "拍手",
                 "拍手蹄仔",
                 "楦闊",
                 "改進",
                 "展翼",
                 "決定",
                 "臭酸",
                 "落伍",
                 "好過",
                 "坐車",
                 "美容",
                 "收盤",
                 "頓落",
                 "迫倚",
                 "穿鞋",
                 "完工",
                 "割開",
                 "穿鞋仔",
                 "穿襪",
                 "穿襪仔",
                 "穿衫",
                 "歹行",
                 "歹勢",
                 "好得",
                 "走閃得",
                 "睏坦覆",
                 "分配",
                 "刣人",
                 "等於",
                 "確定",
                 "閃西風",
                 "賰",
                 "拄",
                 "拄天",
                 "突顯",
                 "燒熱",
                 "過來",
                 "相拍",
                 "支持",
                 "愛護",
                 "愛食",
                 "愛睏",
                 "愛著",
                 "借用",
                 "甘願",
                 "憂悶",
                 "艱苦",
                 "服務",
                 "疼惜",
                 "保重",
                 "調養",
                 "安搭",
                 "還錢",
                 "見笑",
                 "失志",
                 "憑良心",
                 "徛衛兵",
                 "梳妝打扮",
                 "寒人",
                 "熱人",
                 "寫批",
                 "分散",
                 "過日",
                 "過身",
                 "過日子",
                 "期待",
                 "振動",
                 "慶祝",
                 "恐驚",
                 "入門",
                 "破病",
                 "警告",
                 "說明",
                 "交陪",
                 "交接",
                 "做煞",
                 "牽著",
                 "設得",
                 "落肥",
                 "服從",
                 "期待",
                 "模仿",
                 "決算",
                 "決鬥",
                 "沐澹",
                 "淘汰",
                 "演出",
                 "火化",
                 "燒掉",
                 "犯煞",
                 "疲勞",
                 "盲從",
                 "相載",
                 "相隨",
                 "相剋",
                 "看見",
                 "看破",
                 "說破",
                 "點破",
                 "破費",
                 "禁止",
                 "紀念",
                 "贊成",
                 "空嘔",
                 "空襲",
                 "奮鬥",
                 "扣掉",
                 "走便所",
                 "嘔心血",
                 "施肥",
                 "感謝",
                 "延伸",
                 "忍耐",
                 "扣押",
                 "扣除",
                 "扶插",
                 "抽懸",
                 "抽稅",
                 "抽",
                 "拗斷",
                 "捋平",
                 "採用",
                 "提出",
                 "敲破",
                 "牽連",
                 "緊旋",
                 "繼承",
                 "罷免",
                 "義賣",
                 "要求",
                 "強求",
                 "誦經",
                 "超越",
                 "輸出",
                 "退出",
                 "退燒",
                 "過勞",
                 "過濾",
                 "過秤",
                 "遠足",
                 "理解",
                 "注意",
                 "遮光",
                 "替換",
                 "避免",
                 "還俗",
                 "鑑別",
                 "較講",
                 "當做",
                 "飛行",
                 "食紅",
                 "體諒",
                 "高攀",
                 "閃避",
                 "閃過",
                 "閃開",
                 "監督",
                 "熄火",
                 "掠狂",
                 "斟酌",
                 "見赴",
                 "蔫蔫去",
                 "滴落來",
                 "啾啾叫",
                 "講話",
                 "講究",
                 "在生",
                 "講東講西",
                 "記得",
                 "懇求",
                 "得罪",
                 "得著",
                 "值得",
                 "決落去",
                 "唔唔睏",
                 "留長長",
                 "摠規摠",
                 "扒龍船",
                 "拍通關",
                 "顧三頓",
                 "卸世眾",
                 "卸世卸眾",
                 "撙節",
                 "𣁳起來",
                 "摔落",
                 "違反",
                 "死了",
                 "養老",
                 "揣著",
                 "巡視",
                 "遵照",
                 "明知",
                 "弄獅",
                 "發現",
                 "摃破",
                 "得失",
                 "貪著",
                 "刺字",
                 "分魚",
                 "下蹛",
                 "稽考",
                 "阻止",
                 "挾死",
                 "食醋",
                 "煩死",
                 "合喙",
                 "合併",
                 "合唱",
                 "合作",
                 "寬限",
                 "回答",
                 "臭彈",
                 "相對相",
                 "深交",
                 "烏陰",
                 "應聲",
                 "枉死",
                 "頓著",
                 "準",
                 "鼓勵",
                 "鼓舞",
                 "跳舞",
                 "破鼎去",
                 "自殺",
                 "著痧",
                 "出現",
                 "落去",
                 "離開",
                 "開叉",
                 "開學",
                 "開破",
                 "開張",
                 "開放",
                 "開會",
                 "開車",
                 "開鎖",
                 "陷害",
                 "門試",
                 "類推",
                 "保庇",
                 "串通",
                 "伸冤",
                 "伸手",
                 "重句",
                 "戲弄",
                 "枉費",
                 "接載",
                 "趕路",
                 "照顧",
                 "感覺",
                 "規定",
                 "保護",
                 "賠錢",
                 "修養",
                 "修理",
                 "減輕",
                 "珍惜",
                 "畢業",
                 "挽掉",
                 "進步",
                 "拍破",
                 "拍斷",
                 "痴迷",
                 "哼哼呻",
                 "頭轉客",
                 "迷信",
                 "根據",
                 "落來",
                 "討厭",
                 "通報",
                 "敬予",
                 "執政",
                 "欠用",
                 "欠安",
                 "欠數",
                 "交往",
                 "入耳",
                 "串講",
                 "回頭",
                 "回覆",
                 "穢著",
                 "假做",
                 "氣死",
                 "僫講",
                 "硬拗",
                 "惱死",
                 "矮人",
                 "飛",
                 "按",
                 "載",
                 "過",
                 "澄清",
                 "送神",
                 "接神",
                 "報廢",
                 "汙染",
                 "污染",
                 "盡忠",
                 "分派",
                 "灇水",
                 "算會和",
                 "洗門風",
                 "拚暝工",
                 "算袂和",
                 "起衝突",
                 "送做堆",
                 "㧒擲捒",
                 "結綵帶",
                 "刁故意",
                 "照起工",
                 "恐驚見",
                 "著賊偷",
                 "食頭路",
                 "食碰釘",
                 "落空車",
                 "食牢",
                 "通過",
                 "通過關",
                 "洗汰",
                 "請假",
                 "減肥",
                 "心酸",
                 "汰",
                 "卸祖公",
                 "揈落去",
                 "娶入門",
                 "行酒家",
                 "斜過來",
                 "斜目",
                 "滲屎尿",
                 "幌韆鞦",
                 "相照顧",
                 "",
                 "懸",
                 "低",
                 "山",
                 "反來反去",
                 "跩來跩去",
                 "自作自專",
                 "興風作浪",
                 "魚肉鄉民",
                 "激一个氣",
                 "起跤動手",
                 "趒跤頓蹄",
                 "招兵買馬",
                 "想空想縫",
                 "烏青凝血",
                 "消瘦落肉",
                 "準拄煞",
                 "出日頭",
                 "浡出來",
                 "做出來",
                 "提出來",
                 "洩出來",
                 "放落來",
                 "相交插",
                 "做狗爬",
                 "講落去",
                 "講白賊話",
                 "磕袂著",
                 "裝痟的",
                 "激怐怐",
                 "倒踏蹬",
                 "呼倚來",
                 "塌落來",
                 "落落去",
                 "蟯蟯鑽",
                 "填落海",
                 "滿出來",
                 "喀喀嗽",
                 "鼻看嘜",
                 "鼻一下",
                 "摳摳叫",
                 "齁齁叫",
                 "鼾鼾叫",
                 "咂咂叫",
                 "窣窣叫",
                 "跋跋倒",
                 "激五仁",
                 "有準算",
                 "犯太歲",
                 "假死",
                 "過癮",
                 "辦理",
                 "膨風",
                 "膨起來",
                 "誣賴",
                 "拆散",
                 "服侍",
                 "擾亂",
                 "疊衫",
                 "認老",
                 "戀愛",
                 "貪戀",
                 "回批",
                 "自修",
                 "顧擔",
                 "顧人怨",
                 "塌底",
                 "吐血",
                 "臭屁",
                 "歹去",
                 "慼心",
                 "破功",
                 "拆破",
                 "消化",
                 "煏開",
                 "喘氣",
                 "憂愁",
                 "出勤",
                 "出錢",
                 "煩惱",
                 "戇想",
                 "醉酒",
                 "揀食",
                 "墜腸",
                 "計較",
                 "麻煩",
                 "提去",
                 "鎮位",
                 "光臨",
                 "塌空",
                 "保障",
                 "跤球",
                 "聯合",
                 "按算",
                 "留學",
                 "開始",
                 "相拄搪",
                 "硬拄硬",
                 "呷好料",
                 "食好料",
                 "喝酒醉",
                 "啉酒醉",
                 "睏落眠",
                 "搝後跤",
                 "會記得",
                 "搦屎搦尿",
                 "喘",
                 "踮",
                 "插",
                 "印",
                 "烘",
                 "黏",
                 "齪",
                 "替",
                 "摸",
                 "捽",
                 "拗",
                 "用",
                 "拖",
                 "拖累",
                 "害",
                 "改",
                 "坐",
                 "吐",
                 "吵",
                 "予",
                 "出",
                 "加",
                 "開",
                 "關",
                 "活",
                 "欲",
                 "落",
                 "驚",
                 "有",
                 "趁",
                 "攬",
                 "琢",
                 "糝",
                 "嗾",
                 "做",
                 "來",
                 "來去",
                 "萎去",
                 "去",
                 "去掉",
                 "掠",
                 "交",
                 "限",
                 "陷",
                 "響",
                 "領",
                 "願",
                 "錄",
                 "配",
                 "配合",
                 "滑倒",
                 "蹛",
                 "調",
                 "讀",
                 "變",
                 "蹺",
                 "造",
                 "運",
                 "裝",
                 "見",
                 "蓋",
                 "栽",
                 "求",
                 "沖",
                 "沿",
                 "泡",
                 "注",
                 "湧",
                 "煎",
                 "照",
                 "猜",
                 "畫",
                 "眠",
                 "知",
                 "示",
                 "祝",
                 "禁",
                 "租",
                 "種",
                 "穿",
                 "站",
                 "等",
                 "算",
                 "簽",
                 "約",
                 "約束",
                 "睏癖",
                 "捅出來",
                 "享受",
                 "相卸代",
                 "受傷",
                 "結",
                 "經",
                 "縫",
                 "考",
                 "考牢",
                 "聘",
                 "取",
                 "堆",
                 "塗",
                 "墜",
                 "夾",
                 "孵",
                 "射",
                 "巡",
                 "帶",
                 "幫",
                 "幹",
                 "度",
                 "弄",
                 "彈",
                 "念",
                 "怨",
                 "恨",
                 "愛",
                 "憑",
                 "懸",
                 "批",
                 "披",
                 "抿",
                 "拊",
                 "拍",
                 "拔",
                 "招",
                 "指",
                 "捻",
                 "排",
                 "搭",
                 "撇",
                 "擋",
                 "操",
                 "據",
                 "教",
                 "令",
                 "仿",
                 "伐",
                 "作",
                 "供",
                 "信",
                 "倒",
                 "傷",
                 "凍",
                 "剪",
                 "創",
                 "劃",
                 "劫",
                 "動",
                 "包",
                 "升",
                 "㧌",
                 "卡",
                 "食",
                 "飲",
                 "乞",
                 "牽",
                 "笑",
                 "痺",
                 "chai",
                 "lām",
                 "斷去",
                 "鼻著",
                 "恥笑",
                 "失業",
                 "電頭鬃",
                 "生出來",
                 "食外口",
                 "駛入去",
                 "拍交落去",
                 "抾起來",
                 "建設",
                 "做水災",
                 "代課",
                 "出入",
                 "比較",
                 "保證",
                 "近視",
                 "管教",
                 "論輩",
                 "食老",
                 "食歹",
                 "行踏",
                 "把握",
                 "操煩",
                 "老來",
                 "閣來",
                 "安搭",
                 "安養",
                 "分開",
                 "主張",
                 "妥協",
                 "賰錢",
                 "提簿",
                 "毋甘",
                 "磨鏡",
                 "會合",
                 "許配",
                 "處理",
                 "驅煞",
                 "貧血",
                 "強身",
                 "養性",
                 "出破",
                 "體會",
                 "後悔",
                 "中風",
                 "集倚",
                 "死會",
                 "平分",
                 "拍損",
                 "痠軟",
                 "搬有法",
                 "起酒痟",
                 "大細聲",
                 "捽目尾",
                 "上天堂",
                 "貿工程",
                 "現出來",
                 "挻挻年",
                 "縛跤縛手",
                 "tshì-giām", "tsng-thānn", "phùn-tiám", "lo̍k-tē", "bú-jio̍k", "bú-lio̍k", "síng-kang", "puàn-suī", "tah-tah", "kiông-tsè", "tsáu-im", "tap-tshuì-kóo", "tio̍h-tsióng", "tio̍h-tsiáng", "ut-áu", "lo-so", "tsí-hui", "iàu-kín", "khò-sè", "uan-ke", "tshâi-hông", "soo-io", "tàng-sng", "lo̍h-làm", "tsáu-tsua̍h", "kiânn-ta̍h", "si̍p-kuàn", "bûn-sin", "phah-sńg", "khàu-pē", "sái-ba̍k-tsìnn", "pàng-sak", "lâu-nuā", "tsia̍h-tê", "thâi-thâu", "bîng-pi̍k", "liān-siáu-uē", "tsih-tsiap", "ké-siáu", "pit-sûn", "siu-ióng", "nāu-tâi", "tāi-piáu", "tham-tsâi", "tiâu-pak", "sé-bīn", "sué-bīn", "giàng-gê", "khan-suànn", "pháinn-pháng", "phái-pháng", "tuā-siann", "kap-kóo", "sok-io", "piān-hōo", "kíng-kò", "tînn-tuè", "tînn-tè", "kuè-tōo", "kè-tōo", "khé-sī", "kha̍p-thâu", "ián-káng", "that-tshuì-khang", "tò-tuānn", "pó-tsìng", "piàn-siòng", "hué-sio-poo", "hé-sio-poo", "an-the̍h", "ūn-tōng", "tshuán-khuì", "pìnn-lāng", "ìn-uē", "jia-hong", "lia-hong", "thóng-kè", "tsok-gia̍p", "tshē-siàu", "tsuán-tsia̍h", "piànn-miā", "tsáu-su", "tiānn-tio̍h", "ji̍p-sim", "li̍p-sim", "suà-phah", "tōng-uân", "tū-tsuí", "thuah-mn̂g", "tiām-tiām", "tuì-tshuì", "kau-penn", "kau-pinn", "kám-kak", "bâ-tsuì", "ka-la̍uh", "tsiūnn-toh", "bo̍k-bo̍k-siû", "thong-ti", "kau-puê", "hioh-khùn", "tsīng-tsō", "tsú-ì", "thòo-liân-siân", "thàn-tsia̍h", "tsi-tshî", "pháu-bé", "hàu-kìng", "pìnn-kâu-lāng", "tshut-tshiú", "phah-kat-kiû", "uî-lân", "se̍h-thâu", "tah-hing-khám", "tiàu-ko", "î-bîn", "bán-kin", "bán-kun", "khiàm-khueh", "khiàm-kheh", "tàm-thâu", "sin-khóo", "kau-kuah", "kiat-kó", "kuè-óng", "kè-óng", "king-giām", "tiám-hia̍t", "khíng-tīng", "làng-káng", "tshiau-sing", "tsua̍t-lōo", "thàm-thiann", "tuā-hàn", "kenn-si", "kinn-si", "tiùnn-kuân-kè", "siu-suah", "uì-kuânn", "hó-tshuì", "khui-khiàm", "tshiah-hue", "tìn-tè", "sūn-hong", "tio̍h-kâu", "khioh-bah-iù-á", "ióng-tshī", "lo̍h-thôo", "huê-phue", "hê-phue", "teh-sàu", "kiông-kòng", "tsiânn-lâng", "sǹg-siàu", "tsò-thâu", "tsuè-thâu", "pûn-hong", "lī-iōng", "pàng-tshìng", "pa-kiat", "ē-tit-kuè", "ē-tit-kè", "kiám-tiám", "kuè-tshiú", "kè-tshiú", "kui-tīng", "tsiò-kiànn", "pàng-tshiú", "kuái-lōng", "tsàm-kha-pōo", "khuànn-ū", "puê-ióng", "siū-tsuē", "lô-tōng", "pí-jū", "pí-lū", "huan-gîng", "kik-sái", "phiàn-gín-á", "tshiûnn-hong", "kik-kut", "thīn-thâu", "bak-tshiú", "tńg-se̍h", "tsí-sī", "siōng-king", "thàng-hái", "phah-tshenn-kiann", "phah-tshinn-kiann", "tì-ì", "kiàn-siat", "khàu-tshan", "ūn-khì", "kin-suî", "kun-suî", "khui-tshuì", "tsē-uī", "siu-tsông", "tshut-lâi", "pàng-siàu", "tshiúnn-thâu-hiunn", "ngia̍uh-ngia̍uh-sô", "bô--khì", "thiah-phuà", "phah-tshiú", "kè-sǹg", "m̄-guān", "kau-tshap", "píng-pìnn", "ke-uē", "m̄-ta̍t", "tsiù-tshàm", "tsū-kak", "phu̍t-phu̍t-thiàu", "teh--lo̍h-khì", "thiu-tn̂g", "phah-ka-la̍uh", "hong-piān", "suah-bué", "suah-bé", "tông-ki", "tông-ku", "tó-siàu", "pàng-siann", "póo-phuà-bāng", "hau-siâu", "tiám-miâ", "la̍p-tsînn", "kuè-kè", "hūn-bê", "sing-ua̍h", "thiah-phiò", "khui-hue", "tánn-kik", "kin-tuè", "kun-tè", "uá-khò", "ùn tāu-iû", "tshu-phuē", "tshu-phē", "tshim-huān", "kàu-hùn", "thiah-khui", "khu-pia̍t", "siūnn-kóng", "khui-tsho", "thiu-thâu", "hua̍t-lo̍h", "sio-thīn", "bô-hē-lo̍h", "pau-ún", "gōo-huē", "khai-káng", "tsing-sîn", "kau-tsiap", "huan-i̍k", "kuè-lôo", "kè-lôo", "kái-tsong", "kuè-pōng", "kè-pōng", "--hngh", "tsù-siā", "tsáng-thâu", "kng-kiō", "pàng-phuì", "tshuā-thâu", "tîm-té", "tîm-tué", "lí-lūn", "phah-tn̄g", "pái-puah", "hām-bîn", "pàng-ba̍k", "khuànn-phuà", "tsō-huán", "tshiong-kong", "phuà-tiánn", "kau-hīnn", "kau-hī", "lâi-óng", "sîng-jîn", "sîng-lîn", "tsoh-sit", "tánn-tsah", "tsáu-tsông", "tsù-bo̍k", "tām-sám", "khuànn-māi", "hòng-sàng", "ta̍p-tih", "thiàu-tsuí", "tsia̍h-la̍t", "khioh-kíng", "kái-tap", "tāng-tshiú", "tú-tn̄g", "hū-tam", "phì-lūn-kóng", "bih-tshiu", "huan-hù", "tshûn-pān", "tik-sit", "kái-sàn", "tsia̍h-hong", "khiā-khí", "tshòng-tī", "hān-tsè", "ū-té", "ū-tué", "sio-tsing", "kài-siāu", "liam-hiunn", "tsáu-sio-jiok", "tsáu-sio-lip", "khí-pōng", "kiàn-tì", "hàinn-thâu", "tsia̍h-siann", "pài-hāu", "hun-huat", "huan-tsháu", "tò-tńg", "sáng-sè", "ua̍t-thâu", "tshut-thâu", "tò-áu", "e-bí", "sìn-iōng", "tsíng-ām", "su-iânn", "khan-tshiú", "tshut-sán", "tsìn-tsîng", "siat-sióng", "pí-phīng", "tiām--khì", "siu-hīng", "kuānn-tsuí", "khì-tò", "nih-ba̍k", "siu-lí", "tú-tio̍h", "kuàn-tsuí", "khui-to", "suánn-bē", "suánn-buē", "siat-kè", "phoo-pâi", "bīng-līng", "tsha̍k-ba̍k", "ti̍t-ba̍k", "thê-gī", "tsò-buê", "tsuè-buê", "khe-khó", "thê-khí", "tshàng-tshiu", "sio-khiàm-tsè", "an-uì", "hoo-tshiánn", "tsò-tshin-tsiânn", "tsuè-tshin-tsiânn", "lê-tshân", "huán-hîng", "tsih-la̍t", "thong-kuè", "thong-kè", "iah-khang", "lo̍h-tsûn", "ha̍p-sǹg", "óo-khang", "ué-khang", "siu-tiûnn", "làu-ē-hâi", "khuànn-thâu", "kuà-pâi", "khioh-gín-á", "huann-hí", "huê-thâu", "hê-thâu", "kóo-tong", "uí-jīm", "uí-līm", "tsóng-kuán", "kiàn-siàu", "su-tshut", "tháu-pàng", "tsù-tsheh", "lī-tshiú", "hû-tshî", "buah-bīn", "tshia-tó", "tsiap-tshiú", "liām-king", "phah-sǹg", "phòng-hong", "thiàu-bú", "phah-bē", "phah-buē", "tshit-thô", "tsè-koo", "hē-pún", "tshun-tshiú", "tsim-tsiok", "iô-lóo", "kòo-mê", "kòo-mî", "kong-khui", "sio-phah-tiān", "ta-sé", "ta-sué", "tsia̍h-miâ", "lí-kái", "kàu-io̍k", "kuè-tsuí", "kè-tsuí", "tsia̍h-tshài", "ua̍h-tāng", "ke-pô", "siàn-hong", "kau-tài", "au-kiâm-tshài", "pàng-hueh", "pàng-huih", "sing-sán", "bē-tú-hó", "buē-tú-hó", "pò-siau", "kuè-ba̍k", "kè-ba̍k", "huan-thâu", "tsia̍h-tàu", "puânn-tshuì-gím", "tha̍k-tsheh", "tsiūnn-tshiú", "ìn-siann", "ho̍k-sāi", "lîng-tî", "pian-tsi̍p", "pài-tn̂g", "tshiau-kuè", "tshiau-kè", "so-înn", "khan-gû", "ji̍p-mn̂g", "li̍p-mn̂g", "ngē-ah", "ngī-ah", "kiáu-jiáu", "kiáu-liáu", "tsiam-tsǹg", "huat-hiān", "sio-tú", "ngē-áu", "ngī-áu", "tsú-tiunn", "khiā-tâi", "kau-tînn", "hong-siann", "kik-sim", "suà-tshuì-bué", "suà-tshuì-bé", "siu-ji̍p", "siu-li̍p", "tshâi-kuat", "tńg-tshuì", "khui-tshī", "kiàn-gī", "pak-phuê", "pak-phê", "pàng-hún-tsiáu", "pâi-kái", "khui-bīn", "liap-kíng", "pháinn-sí", "huat-lián", "tio̍h-tak", "huan-sin", "âng-ba̍k", "khò-suann", "hì-lāng", "liù-phí-á", "kè-kàu", "iōng-sim", "thún-ta̍h", "siú-tsiat", "tàng-lōo-tsuí", "puann-hì", "tsún-tsò", "tsún-tsuè", "tāi-piān", "sim-būn", "khiā-miâ", "tshē-té", "tshē-tué", "thiàu-tsuā", "tsù-kái", "hōng-sàng", "inn-tînn", "uan-óng", "si̍t-giām", "lo̍h-lâi", "pó-siú", "tshut-kháu", "bô-îng", "kòng-kiû", "kuì-tsuá", "lo̍h-suann", "tiàu-kâu", "tsáu-pio", "tsiong-kun", "bô-tshái", "thè-sî", "thiu-kuân", "thio-hue-tshiah-siù", "tshíng-kiû", "hong-sîn", "tuì-siòng", "khui-tshia", "ho̍k-bū", "hong-tshuì", "pun-tsînn", "lâi-khì", "khai-gia̍p", "kià-thok", "kòo-tīng", "sio-sàng", "kong-khai", "tiàu-tōng", "tò-thè-lu", "thap-khang", "tsìng-bîng", "tso-gū", "khuànn-pēnn", "khuànn-pīnn", "king-kuè", "king-kè", "ta̍h-uē-thâu", "kiong-hí", "tīng-sìng", "siōng-khò", "bô-sè-jī", "bô-suè-lī", "sái-ba̍k-bué", "sái-ba̍k-bé", "pîng-kin", "pîng-kun", "tsia̍h-tsuē", "iáu-siū", "khuànn-bô", "tōng-pông", "su-thong", "tsù-sí", "lo̍h-tsuí", "kàu-tsuí", "suá-phoo", "kuánn-kín", "kuè-khì", "kè-khì", "tshiong-tu̍t", "phuānn-tshuā", "tsìn-thè", "tsō-lōo", "po̍k-lōo", "làu-hong", "lāng-hong", "kè-uē", "hong-so", "lo̍h-khì", "liáu-tsînn", "tò-tiàu", "muá-ì", "tsok-kuài", "tsau-that", "phò-kong", "khui-lōo", "khui-toh", "sin-tshíng", "soo-khai", "hòo-tsuí", "bé-phiò", "bué-phiò", "hāu-póo", "huat-tōng", "kái-kuat", "phah-hué", "phah-hé", "tuì-khuànn", "tshun-ûn", "kuè-nî", "kè-nî", "huê-hok", "hê-hok", "king-li̍k", "tsing-tsha", "káu-sua", "khi-khiau", "pik-tshik", "pik-tshiok", "sian-piànn-sian", "khui-bōo", "liap-sái", "bē-sin", "buē-sin", "tsiap-tshuì", "siau-tháu", "phah-phún", "kiânn-tshun", "khiau-kha", "siâ-sī", "huán-tsíng", "thòo-hueh", "thòo-huih", "thàm-thâu", "khiàm-īng", "kiám-tīng", "puah-kang", "tshut-ji̍p", "tshut-li̍p", "sí-tse̍h", "tio̍h-tse", "tshue-hong", "tshe-hong", "uè-suè", "è-sè", "khu-sok", "kā-tsi̍h", "tsi̍p--tsi̍t-ē", "kái-thuat", "phôo-thánn", "siông-sè", "lo̍h-tâi", "káng-kiù", "phòng-ting", "siu-sok", "tshia̍k-tshia̍k-tiô", "tshuán-tuā-khuì", "tsiânn-mi̍h", "tsiânn-mn̍gh", "uānn-tshiú", "ūn-tsuán", "tshe-kà", "tshut-khîn", "tshut-khûn", "lâu-thng", "liân-huê", "tàng-kah", "gián-kiù", "hàu-koo", "pāi-bé", "tsia̍h-jīn", "tsia̍h-līn", "su-ji̍p", "su-li̍p", "sian-ti", "lak-tshat", "tiâu-ti̍t", "sioh-phuê", "sioh-phê", "tsáu-thiàu", "tshit-kha-tshng", "sún-sit", "ìng-iōng", "se̍h-lin-long", "khòng-bah", "thê-thâu", "tòng-gōng"
             ]